@@ -66,16 +66,13 @@ Details::Details(Procinfo *p, Proc *proc) : QWidget(0)
     if (s0.width() > 800)
         s0.setWidth(800);
     resize(s0);
+    setAttribute(Qt::WA_DeleteOnClose, true);
 }
 
 Details::~Details()
 {
-    //	printf("~Details()\n");
     if (pi)
-        pi->detail = 0;
-    int i;
-    /// for(i=0;i<tbar->count();i++)	delete tbar->page(i);
-    delete tbar;
+        pi->detail = nullptr;
 }
 
 void Details::set_procinfo(Procinfo *p)
@@ -112,9 +109,6 @@ void Details::resizeEvent(QResizeEvent *s)
     QWidget::resizeEvent(s);
 }
 
-// user closed the window (via window manager)
-void Details::closeEvent(QCloseEvent *) { emit closed(this); }
-
 SimpleTable::SimpleTable(QWidget *parent, int nfields, TableField *f,
                          int options)
     : HeadedTable(parent, options), fields(f)
@@ -131,6 +125,8 @@ QSize SimpleTable::sizeHint() const
 
 QString SimpleTable::title(int col) { return fields[col].name; }
 
+QString SimpleTable::dragTitle(int col) { return fields[col].name; }
+
 int SimpleTable::colWidth(int col) { return fields[col].width; }
 
 inline int SimpleTable::alignment(int col) { return fields[col].align; }
@@ -611,11 +607,9 @@ TableField *Environ::fields()
     return fields.data();
 }
 
-Environ *Environ::static_env = 0;
 Environ::Environ(QWidget *parent)
-    : SimpleTable(parent, ENVFIELDS, fields() ), rev(false)
+    : SimpleTable(parent, ENVFIELDS, fields() )
 {
-    connect(this, SIGNAL(titleClicked(int)), SLOT(sort_change(int)));
     refresh();
 }
 
@@ -626,7 +620,7 @@ QString Environ::text(int row, int col)
     Procinfo *p = procinfo(); // if dead process then
     if (row >= p->environ.size())
         printf("size dddd=row=%d\n", row);
-    NameValue nv = p->environ[row]; // Segfault !!
+    NameValue nv = sorted_environs[row];
     return (col == ENVNAME) ? nv.name : nv.value;
 }
 
@@ -634,7 +628,6 @@ void Environ::refresh_window()
 {
     if (!procinfo())
         return;
-    /// resetWidths();
     int rows = procinfo()->environ.size();
     setNumRows(rows);
     setNumCols(ENVFIELDS);
@@ -643,56 +636,18 @@ void Environ::refresh_window()
 
 void Environ::refresh()
 {
-    if (procinfo()->read_environ())
+    if (procinfo() && procinfo()->read_environ())
     {
-        // sort();
+        // sort the variable name column alphabetically
+        sorted_environs = procinfo()->environ;
+        std::sort(sorted_environs.begin(), sorted_environs.end(), [](NameValue a, NameValue b) {
+            return QString::localeAwareCompare(a.name, b.name) < 0;
+        });
+
         refresh_window();
     }
 }
 
-void Environ::sort_change(int col)
-{
-    Procinfo *p = procinfo();
-    /*
-    if(!p->environ) {
-            refresh_environ();
-            if(!p->environ)
-                    return;
-    }*/
-    ////rev = (col == sortedCol()) ? !rev : false;
-    setSortedCol(col);
-    sort();
-    refresh_window();
-}
-
-// sort table according to current settings
-void Environ::sort()
-{
-    /////if(sortedCol() >= 0)
-    {
-        static_env = this;
-        //	if(procinfo()->environ==NULL)
-        //		printf("qps : Environ::sort() error ???\n");
-        //	else
-        //	procinfo()->environ.sort(compare);
-    }
-}
-
-int Environ::compare(const NameValue *a, const NameValue *b)
-{
-    Environ *e = Environ::static_env;
-    int r;
-    /*
-    if(e->sortedCol() == ENVNAME)
-            r = strcmp(a->name, b->name);
-    else
-            r = strcmp(a->value, b->value);  SimpleTable(QWidget *parent,
-    int
-    nfields, TableField *f, int options = 0);
-  */
-    return e->rev ? -r : r;
-}
-
 TableField *AllFields::fields()
 {
     static QVector< TableField > fields( { { tr( "Field" ), -1, 8, Qt::AlignLeft, tr( "Field name" ) }
@@ -718,13 +673,9 @@ AllFields::~AllFields() {}
 QString AllFields::text(int row, int col)
 {
     QString s;
-    // printf("text start r=%d , c=%d\n",row,col);
-    // if( ((Details *)parent())->proc()==NULL)
-    // printf("size=%d\n", ((Details *)parent())->proc()->allcats.size() );
-    // printf("size=%d\n", proc()->allcats.size() );
 
-    Category *cat = proc()->categories.values()[row];
-    //	Category *cat = proc()->allcats[row];
+    Category *cat = sorted_cats[row];
+
     switch (col)
     {
     case FIELDNAME:
@@ -737,7 +688,7 @@ QString AllFields::text(int row, int col)
         s = cat->string(procinfo());
         break;
     }
-    // printf("text end\n");
+
     return s;
 }
 
@@ -754,4 +705,13 @@ void AllFields::refresh_window()
     repaintAll();
 }
 
-void AllFields::refresh() { refresh_window(); }
+void AllFields::refresh()
+{
+    // sort the field name column alphabetically
+    sorted_cats = proc()->categories.values();
+    std::sort(sorted_cats.begin(), sorted_cats.end(), [](Category* a, Category* b) {
+        return QString::localeAwareCompare(a->name, b->name) < 0;
+    });
+
+    refresh_window();
+}
