@@ -33,35 +33,12 @@
 #include "htable.h"
 #include <QMouseEvent>
 #include <QStyleOption>
-#include <QShortcut>
 #include <QPalette>
-
-#define DEBUG qDebug
-//#define DEBUG
-VPointer *vp = NULL; // Temporary
-
-VPointer::VPointer(QWidget *parent) : QWidget(parent)
-{
-    pix = new QPixmap(":/icon/vpointer.png");
-    pix_vcross = new QPixmap(":/icon/vcross.png");
-    int w = pix->width();
-    bool flag_movable = true;
-    setGeometry(0, 0, w, w);
-}
-
-void VPointer::paintEvent(QPaintEvent *event)
-{
-    QPainter p(this);
-    p.setClipping(false); // not work
-    if (flag_movable)
-        p.drawPixmap(0, 0, *pix);
-    else
-        p.drawPixmap(0, 0, *pix_vcross);
-}
+#include <QApplication>
 
 FloatingHead::FloatingHead(QWidget *parent) : QWidget(parent) {}
 
-void FloatingHead::setTitle(QString str, int w, int h)
+void FloatingHead::setTitleAndSize(QString str, int w, int h)
 {
     title = str;
     resize(w, h);
@@ -70,12 +47,14 @@ void FloatingHead::paintEvent(QPaintEvent *event)
 {
     QPainter p(this);
     QStyleOptionHeader opt;
+    opt.orientation = Qt::Horizontal;
+    opt.textAlignment = Qt::AlignVCenter | Qt::AlignLeft;
+    opt.fontMetrics = fontMetrics();
     p.setOpacity(0.7);
     opt.rect = rect();
     opt.text = title;
-    opt.state = QStyle::State_Enabled;
-    // if(htable->sortedCol()==col) opt.state= opt.state |
-    // QStyle::State_Sunken;
+    opt.state = QStyle::State_Enabled | QStyle::State_Horizontal;
+    opt.position = QStyleOptionHeader::OnlyOneSection;
     // CE_Header, CE_HeaderSection, CE_HeaderLabel
     style()->drawControl(QStyle::CE_Header, &opt, &p, this);
     return;
@@ -83,12 +62,15 @@ void FloatingHead::paintEvent(QPaintEvent *event)
 
 // TableHead: the horizontally scrollable table head
 TableHead::TableHead(HeadedTable *parent)
-    : QtTableView(parent), htable(parent), dragging(false)
+    : QtTableView(parent)
+    , htable(parent)
+    , click_col(-1)
+    , right_click_col(-1)
+    , reversed_sort(false)
+    , dragging(false)
+    , drag_offset(0)
 {
     setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
-    // setSizePolicy(QSizePolicy
-    // (QSizePolicy::Minimum,QSizePolicy::Expanding));
-    // setTableFlags(Tbl_smoothHScrolling | Tbl_scrollLastHCell);
     setTableFlags(Tbl_scrollLastHCell); // ?
     setNumRows(1);
 
@@ -96,54 +78,42 @@ TableHead::TableHead(HeadedTable *parent)
 
     floatHead = new FloatingHead(parent); // tiny memory leak! don't care.
     floatHead->hide();
-    // setMinimumHeight(20);//cellHeight()); //ZERO!! fault
+    setLayoutDirection(Qt::LeftToRight); // FIXME: A real fix for RTL is needed!
 }
 
-// Description : draw a field name of table  when DRAG !!
-// 		called by paintHeading()
-// 		called by QtTableView::repaint()
-void TableHead::paintCell(QPainter *p, int row, int col, bool use_cache)
+void TableHead::paintCell(QPainter *p, int /*row*/, int col)
 {
-    static int count = 0;
-    /// printf(" paintcell %d,%d\n",row,col);
     int w = htable->max_widths[col];
 
-    // if( isCellChanged (row,col,true)==false)
-    {
-        //	printf(" paintcell %d,%d\n",row,col);
-        //	if(use_cache==true)  // check cached value
-        {
-            //	return;
-        }
-    }
-
-    // if( col ==11 )	printf("head: %d  (%d) \n",col,count++);
-    // w = cellUpdateR.width();
-    {
-        QStyleOptionHeader opt;
-        QRect rectR(0, 0, w, height());
-        opt.rect = rectR;
-        opt.text = htable->title(col);
-        opt.state = QStyle::State_Enabled;
-        if (htable->sortedCol() == col)
-            opt.state = opt.state | QStyle::State_Sunken;
-        // CE_Header, CE_HeaderSection, CE_HeaderLabel
-        style()->drawControl(QStyle::CE_Header, &opt, p, this);
-    }
-}
-
-// works
-void TableHead::eraseRight(QPainter *p, QRect &r)
-{
     QStyleOptionHeader opt;
-    //		printf("widt=%d \n",r.width());
-    opt.rect = r;
-    opt.text = "";
+    opt.orientation = Qt::Horizontal;
+    opt.textAlignment = Qt::AlignVCenter | Qt::AlignLeft;
+    opt.fontMetrics = fontMetrics();
+    QRect rectR(0, 0, w, height());
+    opt.rect = rectR;
+    opt.text = htable->title(col);
+    opt.state = QStyle::State_Enabled | QStyle::State_Horizontal;
+    opt.section = col; // only KDE styles need this to draw separators
+    opt.position = numCols() == 1 ? QStyleOptionHeader::OnlyOneSection
+                                  : col == 0 ? QStyleOptionHeader::Beginning
+                                             : col == numCols() - 1 ? QStyleOptionHeader::End
+                                                                    : QStyleOptionHeader::Middle;
+    if (col > -1 && htable->sortedCol() == col)
+        opt.sortIndicator = reversed_sort ? QStyleOptionHeader::SortUp
+                                          : QStyleOptionHeader::SortDown;
+    else
+        opt.sortIndicator = QStyleOptionHeader::None;
     style()->drawControl(QStyle::CE_Header, &opt, p, this);
 }
 
+void TableHead::eraseRight(QPainter* /*p*/, QRect& /*r*/)
+{
+    // Do nothing because this is an empty area
+    // with the base background color.
+}
+
 // virtual !
-int TableHead::cellWidth(int col) { return htable->max_widths[col]; }
+int TableHead::cellWidth(int col) const { return htable->max_widths[col]; }
 
 //
 void TableHead::scrollSideways(int val) { setXOffset(val); }
@@ -151,100 +121,51 @@ void TableHead::scrollSideways(int val) { setXOffset(val); }
 void TableHead::mousePressEvent(QMouseEvent *e)
 {
     int col = findCol(e->x());
-    //	printf("col=%d\n",col);
     if (col == -1)
         return;
-    click_col = col;
 
     if (e->button() == Qt::RightButton)
-    // && htable->options & HTBL_HEADING_CONTEXT_MENU)
     {
+        right_click_col = col;
         emit rightClicked(e->globalPos(), col);
-        return;
     }
-
-    if (e->button() == Qt::LeftButton)
+    else if (e->button() == Qt::LeftButton)
     {
+        click_col = col;
         press = e->pos();
     }
 }
 
-void TableHead::dragEnterEvent(QDragEnterEvent *event)
-{
-    printf("dragEnterEvent()\n");
-}
-void TableHead::dragLeaveEvent(QDragLeaveEvent *event)
-{
-    printf("dragLeaveEvent()\n");
-}
-
 void TableHead::mouseMoveEvent(QMouseEvent *e)
 {
-    //	printf("mouseMoveEvent()\n");
     int col = findCol(e->x());
     if (col < 0)
-    {
-        emit htable->outOfHCell();
         return;
-    }
-    //	if( !dragging) return;
-    emit htable->flyOnHCell(col);
 
-    int thold = abs(press.x() - e->pos().x());
-
-    if (e->buttons() == Qt::LeftButton //  Button state
-        and htable->options & HTBL_REORDER_COLS)
+    if (e->buttons() == Qt::LeftButton
+        && (htable->options & HTBL_REORDER_COLS))
     {
+        if (!dragging && abs(press.x() - e->x()) > QApplication::startDragDistance())
         {
-
-            if (!dragging and thold > 5)
+            QString title = htable->dragTitle(click_col);
+            if (!title.isEmpty())
             {
                 dragging = true;
-                drag_offset =
-                    press.x() - htable->colOffset(click_col) + xOffset();
-                floatHead->setTitle(htable->title(click_col),
-                                    cellWidth(click_col), height());
+                drag_offset = press.x() - htable->colOffset(click_col) + xOffset();
+                floatHead->setTitleAndSize(title, cellWidth(click_col), height());
                 floatHead->show();
-                // vp->show();
             }
+        }
 
-            if (dragging)
-            {
-                //	htable->body->drawGhostCol(drag_pos -
-                // drag_offset, w);
-                floatHead->move(e->x() - drag_offset, 0);
-
-                int vcol = findColNoMinus(e->x() - drag_offset);
-                int vcol_offx = htable->colOffset(vcol);
-                static int old_pos = -1;
-                //	printf("vcol=%d\n",vcol);
-
-                // virtual Pointer move!
-                if (old_pos != vcol_offx)
-                {
-                    QWidget *p = parentWidget(); // htable
-                    //	vp->setMovable(htable->columnMovable(htable->columnMovable(vcol)
-                    // and htable->columnMovable(click_col)
-                    // ));
-                    //	vp->move(vcol_offx -
-                    // p->geometry().x()
-                    //,p->geometry().y() -
-                    // 13);
-                    // vp->move(e->x()	,10);
-                    old_pos = vcol_offx;
-                }
-                drag_pos = e->x(); // save old pos
-
-                return;
-            }
+        if (dragging)
+        {
+            floatHead->move(e->x() - drag_offset, 0);
+            return;
         }
     }
 
     if (col != -1) // ToolTip
     {
-        //	for(int i=0;i<1024*1024;i++)	htable->tipText(col);
-        //// memory leak
-        // test
         QString s = htable->tipText(col);
 
         if (!s.isEmpty())
@@ -254,40 +175,38 @@ void TableHead::mouseMoveEvent(QMouseEvent *e)
 
 void TableHead::mouseReleaseEvent(QMouseEvent *e)
 {
-    if (e->button() == Qt::LeftButton) // Returns the button that caused the
-                                       // event.
+    if (e->button() == Qt::LeftButton)
     {
         int col = findCol(e->x());
         if (col < 0)
             col = (e->x() < 0) ? 0 : htable->ncols - 1; // good!
 
-        if (!dragging and col == click_col)
+        if (!dragging) // just a click; no DND
         {
-            // htable->emit_click_signal(col); // just click no drag
-            emit htable->titleClicked(col);
-        }
-
-        if (dragging)
-        {
-            int vcol = findColNoMinus(e->x() - drag_offset);
-            if (click_col >= 0)
+            if (col > -1 && col == click_col)
             {
-                htable->moveCol(click_col, vcol); // call
-                                                  // Pstable::moveCol(int
-                                                  // col, int place)
-                                                  // should emit !!
-                // emit colMoved(click_col, vcol);
+                if (htable->sortedCol() == col) // sorting is reversed
+                    reversed_sort = !reversed_sort;
+                else // sorting will be done based on a new column
+                    reversed_sort = false;
+                emit htable->titleClicked(col);
             }
-            ///	printf(" vcol2=%d \n",vcol);
         }
+        else if (click_col > -1) // dropping
+        {
+            int vcol = findColNoMinus(e->x());
+            htable->moveCol(click_col, vcol); // -> Pstable::moveCol -> Procview::moveColumn
+        }
+        click_col = -1;
         dragging = false;
-        floatHead->hide();
-        // vp->hide();
+        if (floatHead->isVisible())
+        {
+            floatHead->hide();
+            viewport()->update();
+        }
     }
 }
 
-#include <QStyleFactory>
-
 // TableBody: the table body, scrollable in all ways
 TableBody::TableBody(HeadedTable *parent) : QtTableView(parent), htable(parent)
 {
@@ -299,10 +218,7 @@ TableBody::TableBody(HeadedTable *parent) : QtTableView(parent), htable(parent)
     autoscrolling = false;
     gadget_click = false;
     setMouseTracking(true);
-
-    QStyle *s = QStyleFactory::create("windows");
-    if (s)
-        setStyle(s);
+    setLayoutDirection(Qt::LeftToRight); // FIXME: A real fix for RTL is needed!
 }
 
 // virtual from QtTableView
@@ -334,7 +250,7 @@ bool TableBody::isCellChanged(int row, int col)
         str = htable->text(row, col);
         xpos = htable->colXPos(col);
         selected = htable->isSelected(row);
-        sorted = (htable->sortedCol() == col);
+        sorted = (col > -1 && htable->sortedCol() == col);
         width = htable->max_widths[col];
     }
 
@@ -404,50 +320,32 @@ bool TableBody::isCellChanged(int row, int col)
 
 bool TableHead::isCellChanged(int row, int col)
 {
-    int xpos;
-    int ypos;
-    int w;
-    int fold, dep;
-    QString str;
-    bool sorted = (htable->sortedCol() == col);
+    bool sorted = (col > -1 && htable->sortedCol() == col);
 
-    w = htable->max_widths[col];
-    xpos = htable->colXPos(col);
+    if (!dragging && sorted && col == click_col)
+        return true; // sorting is reversed
 
-    {
-        str = htable->title(col);
-    }
-    // int left = leftCell();
-    // int top	 = topCell();
+    bool result = false;
+
+    QString str = htable->title(col);
+    int xpos = htable->colXPos(col);
     CellAttribute *attr = tablecache.value(row - topCell(), col - leftCell());
 
-    if (attr == NULL) // Uninitialed?
+    if (attr == nullptr) // Uninitialed?
     {
-        return true;
+        result = true;
     }
-    else
+    else if (attr->text != str || attr->sorted != sorted
+             || attr->size != tmp_size || attr->xpos != xpos)
     {
-        bool result = false;
-        if (attr->text == str and attr->sorted == sorted and
-            attr->size == tmp_size and attr->xpos == xpos
-            //	and attr->w==w
-            )
-        {
-            return false;
-        }
-        else
-        {
-            attr->text = str;
-            attr->sorted = sorted;
-            attr->xpos = xpos;
-            //		attr->w=w;
-            attr->size = tmp_size;
-            //			if(head)	printf("head
-            // true");
-            return true;
-        }
-        // printf("return  %s x=%d\n",str.toAscii().data(),xpos);
+        attr->text = str;
+        attr->sorted = sorted;
+        attr->xpos = xpos;
+        attr->size = tmp_size;
+        result = true;
     }
+
+    return result;
 }
 
 #include <Qt>
@@ -459,49 +357,25 @@ bool TableHead::isCellChanged(int row, int col)
 //
 // called by
 // 		1.QtTableView::paintEvent()
-void TableBody::paintCell(QPainter *p, int row, int col, bool use_cache)
+void TableBody::paintCell(QPainter *p, int row, int col)
 {
-    // *** sequence important !!!
-    //	if(isCellChanged(row,col)==false)	{
-    // if(use_cache==true)	return;
-    //}
-
     CellAttribute *attr =
         tablecache.value(row - topCell(), col - leftCell()); // save cache
-    //	isCellChanged(row,col);
 
     bool sort;
-    int h = cellHeight();
+    const int h = cellHeight();
     int w = htable->max_widths[col];
-    attr->w = w; //
+    attr->w = w;
 
-    QColor baseColor = palette().brush(QPalette::Base).color();
-    sort = (col == htable->sorted_col);
+    sort = (col > -1 && col == htable->sorted_col);
     attr->sorted = sort;
 
-    // gridline
-    QColor lineColor, textColor;
-    QColor altColor = palette().brush(QPalette::AlternateBase).color();
-    lineColor.setRgb((baseColor.red() * 0.5 + altColor.red() * 0.5),
-                     (baseColor.green() * 0.4 + altColor.green() * 0.6),
-                     (baseColor.blue() * 0.4 + altColor.blue() * 0.6));
-
-    //	QStyleOption opt;
-    //	opt.rect=QRect(0,0,w,h-1);
-    //	opt.state = QStyle::State_Active; //?
-    // QStyle::SH_ItemView_PaintAlternatingRowColorsForEmptyArea
-    //  const int gridHint =
-    //  style()->styleHint(QStyle::SH_Table_GridLineColor,
-    //  &opt, this);
-
-    p->setPen(lineColor);
-    p->drawLine(0, h - 1, w, h - 1);
 
     // background
     if (htable->isSelected(row))
     {
-        p->fillRect(0, 0, w, h - 1, palette().brush(QPalette::Highlight));
-        p->setPen(palette().brush(QPalette::HighlightedText).color()); // text
+        p->fillRect(0, 0, w, h, palette().brush(QPalette::Highlight));
+        p->setPen(palette().color(QPalette::HighlightedText)); // text
         attr->selected = true;
     }
     else
@@ -509,116 +383,108 @@ void TableBody::paintCell(QPainter *p, int row, int col, bool use_cache)
         attr->selected = false;
         if (sort)
         {
-            p->fillRect(0, 0, w, h - 1, lineColor.dark(101));
+            p->fillRect(0, 0, w, h, palette().color(QPalette::AlternateBase));
+        }
+        // the background already has the base color, so there is no need to paint it here
+        /*else
+        {
+            p->fillRect(0, 0, w, h, palette().color(QPalette::Base));
+        }*/
+        p->setPen(palette().color(QPalette::Text)); // text
+    }
+
+    // gridline (QPalette::Mid isn't good enough here)
+    p->save();
+    p->setOpacity(0.1);
+    p->drawLine(0, h - 1, w -1, h - 1);
+    p->restore();
+
+    int align = Qt::AlignVCenter;
+    int gap = h / 4;
+    if (col == 0 && htable->treemode)
+    {
+        p->save();
+        p->setOpacity(0.4); // only to draw branch lines
+
+        QStyleOption opt;
+        const int d = htable->rowDepth(row);
+        attr->depth = d;
+        int treestep = htable->treestep;
+
+        for (int level = d, prow = row; level >= 0 && prow >= 0;
+                level--, prow = htable->parentRow(prow))
+        {
+            if (level == d)
+                continue;
+            int x = gap + level * treestep;
+            if (!htable->lastChild(prow))
+            {
+                p->drawLine(x + treestep / 2, 0, x + treestep / 2, h - 1); // vertical (first branch)
+            }
+        }
+
+        const int x = gap + d * treestep + treestep / 2;
+        p->drawLine(x + 1, h / 2, x + treestep - 1, h / 2); // horizontal
+
+        HeadedTable::NodeState fs = htable->folded(row);
+        attr->folded = fs;
+        if (fs != HeadedTable::Leaf)
+        {
+            opt.state = opt.state | QStyle::State_Children;
+            if (fs != HeadedTable::Closed)
+            {
+                opt.state = opt.state | QStyle::State_Open;
+                p->drawLine(x + treestep, h / 2, x + treestep, h - 1); // vertical (after horizontal line)
+            }
+        }
+
+        if (!htable->lastChild(row))
+        {
+            p->drawLine(x, 0, x, h - 1); // vertical (sub-branch)
         }
         else
         {
-            p->fillRect(0, 0, w, h - 1, baseColor);
+            p->drawLine(x, 0, x, h / 2); // vertical (end)
         }
-        // style()->drawPrimitive(QStyle::PE_FrameFocusRect, &opt, p,
-        // this);
-        p->setPen(palette().brush(QPalette::Text).color()); // text
+        p->restore();
+
+        attr->lastchild = htable->lastChild(row);
+
+        QRect branchR(gap + d * treestep, 0, treestep, h);
+        opt.rect = branchR;
+
+        p->save(); // not really needed
+        style()->drawPrimitive(QStyle::PE_IndicatorBranch, &opt, p, this);
+        p->restore();
+
+        gap = x + treestep + 1;
+        // FIXME: A real fix for RTL is needed!
+        align |= (htable->layoutDirection() == Qt::RightToLeft ? Qt::AlignRight : Qt::AlignLeft);
     }
-
-    // tree gadget , treestep=height
-    int gap = h / 4;
-    int testFlag = 0;
-    if (col == 0 and htable->treemode == true)
+    else
     {
-        QStyleOption opt;
-        int d = htable->rowDepth(row);
-        attr->depth = d; //**
-        int treestep = htable->treestep;
-        if (true /*lines*/)
-        {
-            /// int dx = folding ? gadget_space : 6;
-            for (int level = d, prow = row; level >= 0 and prow >= 0;
-                 level--, prow = htable->parentRow(prow))
-            {
-                if (level == d)
-                    continue;
-                int x = gap + level * treestep;
-                QRect branchR(x, 0, treestep, h);
-                opt.rect = branchR;
-
-                if (htable->lastChild(prow) == false)
-                {
-                    if (testFlag)
-                    {
-                        p->drawLine(x + treestep / 2, 0, x + treestep / 2, h);
-                    }
-                    else
-                    {
-                        opt.state = QStyle::State_Sibling; // | vertical
-                                                           // line
-                        style()->drawPrimitive(QStyle::PE_IndicatorBranch, &opt,
-                                               p, this);
-                    }
-                }
-            }
-
-            QRect branchR(gap + d * treestep, 0, treestep, h);
-            opt.rect = branchR;
-            if (testFlag)
-            {
-                int x = gap + d * treestep + treestep / 2;
-
-                p->drawLine(x, h / 2, x + treestep / 2, h / 2);
-                if (!htable->lastChild(row))
-                {
-                    p->drawLine(x, 0, x, h);
-                }
-                else
-                {
-                    p->drawLine(x, 0, x, h / 2);
-                }
-            }
+        // FIXME: A real fix for RTL is needed!
+        if (htable->layoutDirection() == Qt::RightToLeft)
+        { // reverse the alignment with RTL
+            if (htable->alignment_col[col] == Qt::AlignRight)
+              align |= Qt::AlignLeft;
             else
-            {
-                opt.state = QStyle::State_Item; //?
-                if (!htable->lastChild(row))
-                    opt.state = opt.state | QStyle::State_Sibling; // |
-            }
-            attr->lastchild = htable->lastChild(row);
+              align |= Qt::AlignRight;
         }
-
-        if (true /*folding*/)
+        else
+            align |= htable->alignment_col[col];
+        if (htable->alignment_col[col] == Qt::AlignRight) // using cache
         {
-            HeadedTable::NodeState fs = htable->folded(row);
-            attr->folded = fs; //**
-            if (fs != HeadedTable::Leaf)
-            {
-                opt.state = opt.state | QStyle::State_Children;
-                if (fs != HeadedTable::Closed)
-                    opt.state = opt.state | QStyle::State_Open;
-            }
-            p->save(); // temp , save pencolor
-            style()->drawPrimitive(QStyle::PE_IndicatorBranch, &opt, p, this);
-            p->restore();
+            w -= gap;
+            gap = 0;
         }
-        gap = htable->gadget_space + d * treestep + 1;
     }
 
-    // virtual int Pstable::alignment(int col)
-    if (htable->alignment_col[col] == Qt::AlignRight) // using cache
-    {
-        w -= gap;
-        gap = 0;
-    }
-    // Qt::IncludeTrailingSpaces
-    // p->drawText(gap, 0, w , h, Qt::TextIncludeTrailingSpace |
-    // Qt::IncludeTrailingSpaces | Qt::AlignVCenter |
-    // htable->alignment_col[col],htable->text(row,col));
-    // p->drawText(gap, 0, w , h, Qt::TextIncludeTrailingSpace |
-    // Qt::AlignVCenter
-    // | htable->alignment_col[col],htable->text(row,col));
-    p->drawText(gap, 0, w, h, Qt::AlignVCenter | htable->alignment_col[col],
-                htable->text(row, col));
+    p->drawText(gap, 0, w, h, align, htable->text(row, col));
 
-    htable->overpaintCell(p, row, col, gap);
+    //htable->overpaintCell(p, row, col, gap); // senseless; Pstable::overpaintCell() should be removed
 
     // cache write!
-    // attr->xpos=tmp_x ;
     attr->text = htable->text(row, col);
     attr->xpos = htable->colXPos(col);
     attr->size = tmp_size;
@@ -649,7 +515,7 @@ void TableBody::showRange(int from, int to)
 // virtual
 // called by
 //	1.
-int TableBody::cellWidth(int col) { return htable->max_widths[col]; }
+int TableBody::cellWidth(int col) const { return htable->max_widths[col]; }
 
 // **** fix !!
 void TableBody::updateRow(int row)
@@ -699,11 +565,16 @@ void TableBody::mousePressEvent(QMouseEvent *e)
         if (e->modifiers() & Qt::ShiftModifier)
         {
             if (row < last_row)
+            {
                 for (int i = row; i < last_row; i++)
                     htable->setSelected(i, true); // virtual
+            }
             else
-                for (int i = last_row; i <= row; i++)
+            {
+                int lastRow = qMax(last_row, 0);
+                for (int i = lastRow; i <= row; i++)
                     htable->setSelected(i, true); // virtual
+            }
         }
         else if (e->modifiers() & Qt::ControlModifier)
         {
@@ -867,30 +738,6 @@ void TableBody::dragSelectTo(int row)
     emit htable->selectionChanged();
 }
 
-// heuristic for determining a good XOR color: This is in general a hard
-// problem but since we know (most of) the background and the foreground,
-// we can try. Note that this function might not return an allocated QColor,
-// so it is only useful for XOR drawing.
-
-QColor TableBody::getXorColor()
-{
-    QColor fg = palette().brush(QPalette::Base).color();
-
-    return fg; /// QColor(0, fg.pixel() ^ backgroundColor().pixel());
-}
-
-void TableBody::drawGhostCol(int x, int w)
-{
-    static QColor xorcol = getXorColor();
-
-    QPainter p(this);
-
-    p.setPen(xorcol);
-    // p.setRasterOp(XorROP);
-    /// p.drawLine(x, 0, x, height());
-    ////p.drawLine(x + w, 0, x + w, height());
-}
-
 // HeadedTable: the actually useable class
 HeadedTable::HeadedTable(QWidget *parent, int opts) : QWidget(parent)
 {
@@ -911,59 +758,62 @@ HeadedTable::HeadedTable(QWidget *parent, int opts) : QWidget(parent)
     lines = true;
     folding = true;
     gadget_space = 0;
-    nrows = ncols = 0; // hmm...
+    nrows = ncols = 0;
 
-    // printf("style name=%s \n",qPrintable(style()->objectName()));
-    // QApplication::setStyle(new QWindowsStyle);
     head->setFrameShape(QFrame::NoFrame);
-    if (style()->objectName().contains("oxygen"))
-        ;
-    else
-    {
-        body->setFrameShape(QFrame::NoFrame);
-    }
+    body->setFrameShape(QFrame::NoFrame);
 
     QVBoxLayout *vlayout = new QVBoxLayout;
-    vlayout->setSpacing(0); // distance between Widget and Widget
+    vlayout->setSpacing(0);
 
-#if QT_VERSION < 0x040300
-    vlayout->setMargin(0); // qt-4.2
-#else
-    vlayout->setContentsMargins(0, 0, 0, 0); // qt-4.3
-#endif
+    vlayout->setContentsMargins(0, 0, 0, 0);
 
-    //	vlayout->setSizeConstraint ( SizeConstraint )
     vlayout->addWidget(head);
     vlayout->addWidget(body);
     setLayout(vlayout);
 
-    // connect keyboard shortcuts
-    QShortcut *c;
-    c = new QShortcut(Qt::CTRL + Qt::Key_A, this, SLOT(selectAll()));
     // synchronize horizontal scrolling of head and body
     connect(body->horizontalScrollBar(), SIGNAL(valueChanged(int)), head,
             SLOT(scrollSideways(int)));
-    fontChange(font()); // *** need for init
-                        //	vp=new VPointer((QWidget *)QObject::parent());
-                        //	vp->hide();		//memory leak!!
+
+    // NOTE: It isn't enough to consider the font here because it may change at startup.
+    // Instead, it will be taken into account when QEvent::FontChange() is sent.
+    fontChange();
 }
 
 HeadedTable::~HeadedTable() {}
 
-// ok : move to Qttableview
-void HeadedTable::fontChange(const QFont &oldFont)
+bool HeadedTable::event(QEvent *event)
 {
-    // DEBUG("fontChange()\n");
-    int fontHeight = fontMetrics().height() + 1;
-    // printf("cell height =%d \n", cellH);
-    if (fontHeight % 2 != 0)
-        fontHeight++; // for pretty fold-lines
-    head->setCellHeight(fontHeight + 5);
+    if (event->type() == QEvent::FontChange)
+        fontChange();
+    return QWidget::event(event);
+}
+
+// Find the correct heights of header and body cells with the current font
+void HeadedTable::fontChange()
+{
+    // let the widget style calculate the heights
+
+    QStyleOptionHeader opt;
+    opt.textAlignment = Qt::AlignVCenter | Qt::AlignLeft;
+    opt.orientation = Qt::Horizontal;
+    opt.fontMetrics = fontMetrics();
+    opt.text = "W"; // not really needed because all sane styles consider the font height
+    opt.sortIndicator = QStyleOptionHeader::SortDown; // to have space for a sort indicator
+    int H = style()->sizeFromContents(QStyle::CT_HeaderSection, &opt, QSize(), head).height();
+    if (H % 2 != 0) H++;
+    head->setCellHeight(H);
     head->setMaximumHeight(head->cellHeight());
+
+    QStyleOptionViewItem ivOpt;
+    ivOpt.fontMetrics = fontMetrics();
+    int fontHeight = style()->sizeFromContents(QStyle::CT_ItemViewItem, &ivOpt, QSize(), this).height();
+    if (fontHeight % 2 != 0) fontHeight++;
+
     body->setCellHeight(fontHeight);
     treestep = fontHeight;
     gadget_space = folding ? fontHeight + (fontHeight / 2) : 0;
-    //	QWidget::fontChange ( oldFont );
 }
 
 // DRAFT  virtual !
@@ -1028,19 +878,18 @@ void HeadedTable::setTreeMode(bool tm)
     body->clearCache();
 }
 
+int HeadedTable::tableWidth() const
+{
+    QScrollBar *vs = body->verticalScrollBar();
+    bool hidden = vs->minimum() == vs->maximum() // instead of !isVisible(), if update is paused
+                  || vs->style()->styleHint(QStyle::SH_ScrollBar_Transient, nullptr, vs);
+    return body->totalWidth() + (hidden ? 0 : vs->style()->pixelMetric(QStyle::PM_ScrollBarExtent));
+}
+
 // update table Head !!
 void HeadedTable::setSortedCol(int col)
 {
-    {
-        int old_sorted = sorted_col;
-        sorted_col = col;
-        //		printf("old_sorted=%d\n",old_sorted);
-        //		printf("sorted_col=%d\n",sorted_col);
-        if (old_sorted != -1 && old_sorted < ncols) // ncols bug
-            updateHeading(old_sorted);
-        if (col != -1 && col < ncols)
-            updateHeading(col);
-    }
+    sorted_col = col;
 }
 
 // should be virtual. why?
@@ -1049,13 +898,10 @@ void HeadedTable::clearAllSelections()
     for (int row = 0; row < nrows; row++)
         setSelected(row, false);
     body->view->update();
-    //	update(); // not work why?
 }
 
-// BottleNeck ?
 void HeadedTable::selectOnlyOne(int row)
 {
-    // this apply to the current list only!
     for (int r = 0; r < nrows; r++)
         setSelected(r, r == row);
 }
@@ -1064,18 +910,24 @@ void HeadedTable::selectAll()
 {
     for (int r = 0; r < nrows; r++)
         setSelected(r, true);
-    emit selectionChanged(); // notwork?
+    emit selectionChanged();
 }
 
 // default implementation returns a null string (no tip d)
 QString HeadedTable::tipText(int) { return ""; }
 char *HeadedTable::total_selectedRow(int col) { return 0; }
 
+// should be called before setNumCols()
 void HeadedTable::setNumRows(int rows)
 {
     nrows = rows;
     head->setNumRows(1);
     body->setNumRows(rows);
+
+    // if update is paused or we don't want to wait for it;
+    // to be used to spread the last column in updateColWidth()
+    // (updateTable will be called in setNumCols)
+    body->updateScrollBars();
 }
 
 void TableCache::setRow(int row)
@@ -1148,10 +1000,9 @@ void TableBody::checkProfile()
     tablecache.setRow(maxViewRow);
 }
 
+// should be called after setNumRows()
 void HeadedTable::setNumCols(int cols)
 {
-    // printf("cols=%d\n",cols);
-
     ncols = cols;
     // resetWidths();
     for (int i = 0; i < cols; i++)
@@ -1159,64 +1010,73 @@ void HeadedTable::setNumCols(int cols)
         alignment_col[i] = alignment(i);
         updateColWidth(i);
     }
-    //	printf("ncols=%d\n",ncols);
     head->setNumCols(ncols);
     body->setNumCols(ncols);
+
+    // WARNING: The scrollbars, table viewport and offsets should be
+    // updated here for the table and header widths to be correct.
+    updateTable();
 }
 
-/*
-//virtual
-int HeadedTable::colWidth(int col)
-{
-        int r = numRows();
-        for(int i=0;i<r;i++)	text(i,col);
-} */
-
-// BOTTLENECK
-// find Max width of a column
-// called by
-//		1.  void HeadedTable::setNumCols(int cols)
-int HeadedTable::updateColWidth(int col)
+void HeadedTable::updateColWidth(int col)
 {
     int w = 0;
     int sw = 0;
-    int hw = 0;
-    int i = 0;
     int rows = numRows();
     bool treecol = (treemode && col == 0);
 
-    if ((w = sizeHintForColumn(col)) < 0) // width
+    for (int i = 0; i < rows; i++)
     {
-        if (w < 0)
-            w = -w; // trick.
-        // if(w<0) printf("w = %d\n",w);
-        // harsh, if procs more than 1000
-        for (i = 0; i < rows; i++)
-        {
-            sw = fontMetrics().width(text(i, col)) + 10;
-
-            if (treecol)
-                sw += treestep * rowDepth(i);
-            if (sw > w)
-                w = sw;
-        }
-
+#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
+        sw = fontMetrics().horizontalAdvance(text(i, col)) + 10;
+#else
+        sw = fontMetrics().width(text(i, col)) + 10;
+#endif
         if (treecol)
-        {
-            w += gadget_space;
-        }
+            sw += treestep * rowDepth(i);
+        if (sw > w)
+            w = sw;
     }
-    // don't forget the width of the heading
-    hw = fontMetrics().width(title(col)) + 12;
-    // return 0;
+
+    if (treecol)
+    {
+        w += gadget_space;
+    }
+
+    // get the header width by consulting the widget style
+    QStyleOptionHeader opt;
+    opt.orientation = Qt::Horizontal;
+    opt.textAlignment = Qt::AlignVCenter | Qt::AlignLeft;
+    opt.fontMetrics = fontMetrics();
+    opt.text = title(col);
+    opt.sortIndicator = QStyleOptionHeader::SortDown;
+    int hw = style()->sizeFromContents(QStyle::CT_HeaderSection, &opt, QSize(), this).width();
+
     if (hw > w)
         w = hw;
 
-    // sw=fontmetric.width("0") * colWidth(col);
-    // if(sw>w) w=sw;
+    // to have an elegant table, spread the last column if its contents are left aligned
+    if (col == ncols - 1 && alignment_col[col] == Qt::AlignLeft)
+    {
+        int prevWidths = 0;
+        for (int i = 0 ; i < col; i++)
+            prevWidths += max_widths[i];
+        QScrollBar *vs = body->verticalScrollBar();
+        bool hidden = vs->minimum() == vs->maximum() // instead of !isVisible(), if update is paused
+                      || vs->style()->styleHint(QStyle::SH_ScrollBar_Transient, nullptr, vs);
+        int scrollWidth = hidden ? 0 : vs->style()->pixelMetric(QStyle::PM_ScrollBarExtent);
+        w = qMax(w, width() - scrollWidth - prevWidths);
+    }
 
     max_widths[col] = w;
-    return 0;
+}
+
+void HeadedTable::updateTable()
+{
+    body->updateOffsets();
+    head->updateOffsets();
+    body->updateScrollBars();
+    body->viewport()->update();
 }
 
 void HeadedTable::resetWidths()
@@ -1283,6 +1143,11 @@ void HeadedTable::resizeEvent(QResizeEvent *e)
     // DEBUG("resizeEvent() HeadedTable %d\n",head->cellHeight());
     ////	head->repaintRow(0);
     QWidget::resizeEvent(e);
+
+    // update the width of the last column
+    updateColWidth(numCols() - 1);
+    updateTable();
+
     head->clearCache();
     body->clearCache();
 }
