@@ -83,14 +83,17 @@ class TableCache
   public:
     TableCache()
     {
-        // for(int i=0;i<1;i++) // tmp
         rows.append(new TableRow);
         nrow = 0;
         ncol = 0;
     }
 
-    void reset() {} // clear cache
-    void setSize(int row, int col);
+    ~TableCache()
+    {
+        while (rows.size() > 0)
+            delete rows.takeFirst();
+    }
+
     void setRow(int row);
     void setCol(int col);
 
@@ -125,32 +128,14 @@ class TableCache
     }
 };
 
-class VPointer : public QWidget
-{
-    Q_OBJECT
-  public:
-    VPointer(QWidget *parent);
-    QPixmap *pix;
-    QPixmap *pix_vcross;
-    void setMovable(bool b) { flag_movable = b; }
-    bool flag_movable;
-  protected slots:
-    //		void event_cursor_moved(QMouseEvent *e);
-  protected:
-    // virtual void drawButton 3( QPainter * ) ;
-    virtual void paintEvent(QPaintEvent *event);
-    //	void resizeEvent(QResizeEvent *p);
-};
-
 class FloatingHead : public QWidget
 {
     Q_OBJECT
   public:
     FloatingHead(QWidget *parent);
-    QPixmap *pix;
-    void setTitle(QString str, int w, int h);
+    void setTitleAndSize(QString str, int w, int h);
     QString title;
-  protected slots:
+
   protected:
     virtual void paintEvent(QPaintEvent *event);
 };
@@ -163,29 +148,31 @@ class TableHead : public QtTableView
     TableHead(HeadedTable *parent = 0);
     virtual bool isCellChanged(int row, int col);
     virtual void checkProfile();
+    void setReveseSort(bool reverse) {
+        reversed_sort = reverse;
+    }
 
   protected slots:
     void scrollSideways(int);
 
   protected:
-    virtual void paintCell(QPainter *p, int row, int col, bool update);
-    virtual int cellWidth(int col);
+    virtual void paintCell(QPainter *p, int row, int col);
+    virtual int cellWidth(int col) const;
     virtual void mousePressEvent(QMouseEvent *e);
     virtual void mouseReleaseEvent(QMouseEvent *e);
     virtual void mouseMoveEvent(QMouseEvent *e);
     virtual void eraseRight(QPainter *, QRect &r);
 
-    virtual void dragEnterEvent(QDragEnterEvent *event);
-    virtual void dragLeaveEvent(QDragLeaveEvent *event);
-
     FloatingHead *floatHead;
 
     HeadedTable *htable; // to access parent class
     QPoint press;
     int click_col; // physical column clicked in
+    int right_click_col;
+    bool reversed_sort; // true if sorting backwards
     bool dragging;
-    int drag_pos; // previous dragging position
     int drag_offset;
+
 signals:
     void rightClicked(QPoint where, int col);
     void toolTip(QPoint where, int col);
@@ -199,8 +186,6 @@ class TableBody : public QtTableView
   public:
     TableCache tablecache;
     TableBody(HeadedTable *parent = 0);
-    void drawGhostCol(int x, int w);
-    // int zerowidth;		// width of the digit 0
 
     virtual bool isCellChanged(int row, int col);
     virtual void checkProfile();
@@ -214,8 +199,8 @@ class TableBody : public QtTableView
   protected:
     virtual void scrollTrigger(int x, int y); // tmp
 
-    virtual void paintCell(QPainter *p, int row, int col, bool forced);
-    virtual int cellWidth(int col);
+    virtual void paintCell(QPainter *p, int row, int col);
+    virtual int cellWidth(int col) const;
     void mousePressEvent(QMouseEvent *e);
     void mouseDoubleClickEvent(QMouseEvent *e);
     void mouseMoveEvent(QMouseEvent *e);
@@ -225,7 +210,6 @@ class TableBody : public QtTableView
     void timerEvent(QTimerEvent *);
     void updateRow(int row);
     void dragSelectTo(int row);
-    QColor getXorColor();
     HeadedTable *htable; // to access parent class
     int first_drag_row;  // row where drag started
     int prev_drag_row;   // row where drag was at last event
@@ -263,7 +247,7 @@ class HeadedTable : public QWidget
     };
 
     void repaint_changed();
-    int updateColWidth(int col);
+    void updateColWidth(int col);
 
     void resetWidths();
     void resetWidth(int col) { max_widths[col] = -1; } // dont use ?
@@ -275,35 +259,28 @@ class HeadedTable : public QWidget
     void setNumRows(int rows);
     void setNumCols(int cols);
     int clickedColumn() { return head->click_col; }
+    int rightClickedColumn() { return head->right_click_col; }
     void deleteCol(int col, bool update = true);
-    int leftCell() { return body->leftCell(); };
-    int lastColVisible() { return body->lastColVisible(); };
-    int topCell() { return body->topCell(); };
-    int lastRowVisible() { return body->lastRowVisible(); };
+    int leftCell() { return body->leftCell(); }
+    int lastColVisible() { return body->lastColVisible(); }
+    int topCell() { return body->topCell(); }
+    int lastRowVisible() { return body->lastRowVisible(); }
     void updateCell(int row, int col, bool erase = false);
-    void updateHeading(int col){/* head->updateCell(0, col); */};
-    void setAutoUpdate(bool update)
-    {
-        head->setAutoUpdate(update);
-        body->setAutoUpdate(update);
-    };
-    void centerVertically(int row) { body->centerVertically(row); };
-    void showRange(int from, int to) { body->showRange(from, to); };
+    void centerVertically(int row) { body->centerVertically(row); }
+    void showRange(int from, int to) { body->showRange(from, to); }
     void repaintColumns(int col0, int col1 = -1);
     void setTreeMode(bool tm);
-    bool treeMode() { return treemode; };
-    int tableWidth() const
-    {
-        return body->totalWidth() + body->verticalScrollBar()->width();
-    }
+    bool treeMode() { return treemode; }
+    int tableWidth() const;
 
     void selectOnlyOne(int row);
     int numSelected() { return 0; }
     void clearAllSelections();
+    void selectAll();
 
-    virtual void setSelected(int row, bool sel){};
+    virtual void setSelected(int row, bool sel){}
     virtual bool isSelected(int row) { return false; }
-    virtual void checkTableModel(){};
+    virtual void checkTableModel(){}
 signals:
     void titleClicked(int col);
     void selectionChanged();
@@ -312,24 +289,21 @@ signals:
     void foldSubTree(int row);
     void colMoved(int col, int place);
     void flyOnCell(int row, int col);
-    void flyOnHCell(int col);
     void outOfCell();
-    void outOfHCell();
 
   public slots:
-    void selectAll();
     void repaintAll();
 
   protected:
-    void fontChange(const QFont &oldFont);
+    virtual bool event(QEvent *event);
     // These must be implemented in subclasses
     virtual QString title(int col) = 0;
+    virtual QString dragTitle(int col) = 0;
     virtual QString text(int row, int col) = 0;
     virtual char *total_selectedRow(int col);
     // colWidth returns width in digit units; negative means variable width.
     virtual int colWidth(int col) = 0; // head_width
     virtual int alignment(int col) { return 0; }
-    virtual int sizeHintForColumn(int col) const { return -1; }
     virtual void paintEvent(QPaintEvent *);
     virtual void hideEvent(QHideEvent *event);
     virtual void showEvent(QShowEvent *event);
@@ -338,13 +312,13 @@ signals:
     virtual void moveCol(int col, int place);
 
     virtual QString tipText(int col);
-    virtual int rowDepth(int row) { return 0; };
-    virtual NodeState folded(int row) { return Leaf; };
-    virtual int parentRow(int row) { return 0; };
-    virtual bool lastChild(int row) { return false; };
-    virtual bool columnMovable(int col) { return true; };
+    virtual int rowDepth(int row) { return 0; }
+    virtual NodeState folded(int row) { return Leaf; }
+    virtual int parentRow(int row) { return 0; }
+    virtual bool lastChild(int row) { return false; }
+    virtual bool columnMovable(int col) { return true; }
     // virtual bool modified(int row){return true;};
-    virtual void overpaintCell(QPainter *p, int row, int col, int xpos){};
+    virtual void overpaintCell(QPainter *p, int row, int col, int xpos){}
 
     void resizeEvent(QResizeEvent *);
 
@@ -352,10 +326,11 @@ signals:
     int treestep; // indentation for each tree level
 
   private:
+    void fontChange();
     inline int computedWidth(int col);
     int colOffset(int col);
     inline int colXPos(int col);
-    void updateCols(int deltacols, int place, bool update);
+    void updateTable();
 
     int alignment_col[64];
     int headwidth_col[64];
@@ -363,7 +338,6 @@ signals:
     // Svec<int> widths;		// row widths, indexed by columns
 
     int sorted_col;    // column to emphasize
-    int reversed_sort; // true if sorting backwards
     int options;
     int nrows;
     int ncols;
