@@ -867,7 +867,6 @@ void GraphBase::mouseMoveEvent(QMouseEvent *e)
     // gap=infobox->width() + px  - width();
 
     int i;
-    int setinfo = 0;
 
     // printf("procview npoints=%d  px=%d\n",npoints,px);
     QString text;
@@ -883,8 +882,7 @@ void GraphBase::mouseMoveEvent(QMouseEvent *e)
         // text ="xxx";
     }
 
-    if (setinfo == 0)
-        infobox->setText(text);
+    infobox->setText(text);
 
     QPoint p = mapTo(qps, e->pos()); //??
 
@@ -1318,7 +1316,6 @@ void subcpuRack::paintEvent(QPaintEvent *e)
     QPainter p(this);
     char buff[128];
     int w;
-    int width;
     int x, y;
     int i;
     // QRect cr = contentsRect();
@@ -1337,7 +1334,6 @@ void subcpuRack::paintEvent(QPaintEvent *e)
     // else
     int cpu_n = procview->num_cpus;
     w = 2 + pf_write(&p, 2, 2, "SUB CPU");
-    width = w;
 }
 
 // GraphDisplay, miniDisplay
