@@ -141,33 +141,6 @@ class TBloon : public QLabel
     QTimeLine *timeLine;
 };
 
-class FaderWidget : public QWidget
-{
-    Q_OBJECT
-    Q_PROPERTY(QBrush fadeBrush READ fadeBrush WRITE setFadeBrush)
-    Q_PROPERTY(int fadeDuration READ fadeDuration WRITE setFadeDuration)
-  public:
-    FaderWidget(QWidget *parent);
-
-    QBrush fadeBrush() const { return startBrush; }
-    void setFadeBrush(const QBrush &newColor) { startBrush = newColor; }
-
-    int fadeDuration() const { return timeLine->duration(); }
-    void setFadeDuration(int milliseconds)
-    {
-        timeLine->setDuration(milliseconds);
-    }
-
-    void start();
-
-  protected:
-    void paintEvent(QPaintEvent *event);
-
-  private:
-    QTimeLine *timeLine;
-    QBrush startBrush;
-};
-
 class UFrame : public QFrame
 {
     Q_OBJECT
@@ -211,15 +184,8 @@ class SearchBox : public QLineEdit
     void event_cursor_moved(QMouseEvent *e);
     void keyPressEvent(QKeyEvent *e);
   protected slots:
+    void onClearButtonClicked();
     void event_xbutton_clicked();
-    //    		void refresh();
-    //  		void update(int n);
-    //		QToolButton *button,*button2,*button3;
-  protected:
-    void resizeEvent(QResizeEvent *);
-    void timerEvent(QTimerEvent *);
-    int left_time;
-    //	XButton *xb;
 };
 
 class LogBox : public QLabel
@@ -236,9 +202,8 @@ class StatusBar : public QStatusBar
     Q_OBJECT
   public:
     StatusBar(QWidget *parent);
-    void refresh();
     void update(int n);
-    QLabel *label, *label2, *label3;
+    QLabel *label;
 };
 
 class ControlBar : public QFrame
@@ -248,7 +213,7 @@ class ControlBar : public QFrame
     QComboBox *view;
     ControlBar(QWidget *parent);
     void setMode(bool treemode);
-    void update_bar();
+
     QToolButton *pauseButton;
 
 signals:
@@ -261,13 +226,8 @@ signals:
     void view_changed(int idx);
     void tree_clicked();
     void show_thread_clicked();
-    void event_search_box_changed();
-    void event_command_pressed();
     void setPaused(bool);
 
-  protected:
-    void resizeEvent(QResizeEvent *);
-
   private:
     QRadioButton *b_tree, *b_linear, *b_treeT;
     QCheckBox *check_thread;
