@@ -61,8 +61,6 @@
 
 #define PROCDIR "/proc" // hmmm
 
-bool flag_SMPsim = false; // SMP simulation
-
 extern int flag_thread_ok;
 extern bool flag_schedstat;
 extern bool flag_show_thread;
@@ -231,7 +229,7 @@ char *read_proc_file2(char *r_path, const char *fname, int *size = NULL)
 // Description: read /proc/PID/fd/*  check opened file, count opened files
 //		this fuction will be called  when every update.
 // Return Value :
-int proc_pid_fd(const int pid)
+bool proc_pid_fd(const int pid)
 {
     char path[256];
     char buffer[256], fname[256];
@@ -319,6 +317,7 @@ Procinfo::Procinfo(Proc *system_proc, int process_id, int thread_id) : refcnt(1)
     stack = 0;
     share = 0;
     mem = 0;
+    swap = 0;
 
     io_read_prev = 0; // **
     io_write_prev = 0;
@@ -359,6 +358,15 @@ Procinfo::~Procinfo()
             detail = 0;
         }
 
+        qDeleteAll(sock_inodes.begin(), sock_inodes.end());
+        sock_inodes.clear();
+
+        qDeleteAll(fd_files.begin(), fd_files.end());
+        fd_files.clear();
+
+        qDeleteAll(maps.begin(), maps.end());
+        maps.clear();
+
         //    if(environ)    delete environ;
         if (envblock)
             free(envblock); /// double free , SEGFAULT
@@ -833,6 +841,8 @@ int Procinfo::readproc()
             mini_sscanf(buf, "VmStk: %d", &stack); // stack	in kByte
             mini_sscanf(buf, "VmExe: %d", &trs);   // text
         }
+        if (strstr(buf, "VmSwap:"))
+            mini_sscanf(buf, "VmSwap: %d", &swap);   // swap in kByte
     }
 
     /*
@@ -942,14 +952,6 @@ int Proc::countCpu()
         if (p)
             p++;
     }
-
-    if (flag_devel and flag_SMPsim)
-    {
-        // num_cpus=64;
-        int vals[] = {2, 4, 8, 16, 32};
-        int r = rand() % 5;
-        num_cpus = vals[r];
-    }
     return num_cpus;
 }
 
@@ -1005,7 +1007,7 @@ int Proc::read_system() //
             p += 6;
             // sscanf(p, "%d", &Proc::boot_time); //???? why
             // segfault???
-            sscanf(p, "%d", &boot_time);
+            sscanf(p, "%u", &boot_time);
         }
 
         // Max SMP 1024 cpus,  MOVETO: COMMON
@@ -1052,14 +1054,6 @@ int Proc::read_system() //
                 p++;
         }
 
-        if (flag_SMPsim)
-        {
-            int vals[] = {2, 4, 8, 16, 32};
-            int r = rand() % 5;
-            num_cpus = vals[r];
-            num_cpus = 8;
-        }
-
         // Hotplugging Detection : save total_cpu
         if (Proc::num_cpus != Proc::old_num_cpus)
         {
@@ -1144,66 +1138,38 @@ int Proc::read_system() //
                         // abort(); // stdlib.h
     }
 
-    //	void watchdog_syscpu(int );
-    //	watchdog_syscpu((user-old_cpu_times(num_cpus,CPUTIME_USER))*100/dt_total);
-    //// test
-
-    // if(flag_devel and flag_SMPsim )
-    if (flag_SMPsim)
+    for (int cpu = 0; cpu < num_cpus; cpu++)
     {
-        // for Developer only !!!
-        // printf("user%d nuce%d system%d
-        // idle%d\n",user,nice,system,idle);
-        for (int cpu = 0; cpu < num_cpus; cpu++)
+        char cpu_buf[10];
+        sprintf(cpu_buf, "cpu%d", cpu);
+        if ((p = strstr(buf, cpu_buf)) != 0)
         {
-            // stdlib.h, int rand();
-            if (dt_used != 0)
-                cpu_times(cpu, CPUTIME_USER) =
-                    old_cpu_times(cpu, CPUTIME_USER) + rand() % dt_used;
-            else
-                cpu_times(cpu, CPUTIME_USER) = 0;
-            cpu_times(cpu, CPUTIME_NICE) = nice;
-            cpu_times(cpu, CPUTIME_SYSTEM) = system;
-            cpu_times(cpu, CPUTIME_IDLE) = idle;
+            nflds = sscanf(p, "%*s %u %u %u %u %u %u %u %u %u",
+                           &cpu_times(cpu, CPUTIME_USER),
+                           &cpu_times(cpu, CPUTIME_NICE),
+                           &cpu_times(cpu, CPUTIME_SYSTEM),
+                           &cpu_times(cpu, CPUTIME_IDLE), &iowait, &irq,
+                           &sftirq, &steal, &guest);
+
+            if (nflds > 4)
+            {
+                // kernel 2.6.x
+                cpu_times(cpu, CPUTIME_SYSTEM) += (irq + sftirq);
+                cpu_times(cpu, CPUTIME_IDLE) += iowait;
+            }
+            if (nflds == 9)
+            {
+                cpu_times(cpu, CPUTIME_SYSTEM) += (steal + guest);
+            }
+
+            // 2.4.27-SMP bug ?
         }
-    }
-    else
-    {
-        // Single-CPU and SMP(Multi-CPU)
-        for (int cpu = 0; cpu < num_cpus; cpu++)
+        else
         {
-            char cpu_buf[10];
-            sprintf(cpu_buf, "cpu%d", cpu);
-            if ((p = strstr(buf, cpu_buf)) != 0)
-            {
-                nflds = sscanf(p, "%*s %u %u %u %u %u %u %u %u %u",
-                               &cpu_times(cpu, CPUTIME_USER),
-                               &cpu_times(cpu, CPUTIME_NICE),
-                               &cpu_times(cpu, CPUTIME_SYSTEM),
-                               &cpu_times(cpu, CPUTIME_IDLE), &iowait, &irq,
-                               &sftirq, &steal, &guest);
-                // cpu_times(cpu, CPUTIME_USER),cpu_times(cpu,
-                // CPUTIME_NICE),
-                if (nflds > 4)
-                {
-                    // kernel 2.6.x
-                    cpu_times(cpu, CPUTIME_SYSTEM) += (irq + sftirq);
-                    cpu_times(cpu, CPUTIME_IDLE) += iowait;
-                }
-                if (nflds == 9)
-                {
-                    cpu_times(cpu, CPUTIME_SYSTEM) += (steal + guest);
-                }
-
-                // 2.4.27-SMP bug ?
-            }
-            else
-            {
-                fprintf(stderr, "Qps: Error reading info for "
-                                "cpu%d (/proc/stat)\n",
-                        cpu);
-                abort();
-            }
+            fprintf(stderr, "Qps: Error reading info for "
+                            "cpu%d (/proc/stat)\n",
+                    cpu);
+            abort();
         }
     }
 
@@ -1543,6 +1509,10 @@ void Proc::invalidate_sockets() { socks_current = usocks_current = false; }
 // return true if /proc/XX/maps could be read, false otherwise
 bool Procinfo::read_maps()
 {
+    // prevent memory leak
+    qDeleteAll(maps.begin(), maps.end());
+    maps.clear();
+
     // idea: here we could readlink /proc/XX/exe to identify the executable
     // when running 2.0.x
     char name[80];
@@ -1610,18 +1580,6 @@ bool Procinfo::read_environ()
     if (size <= 0)
         return false;
 
-    // kernel 2.6.x has a bug
-    if (envblock[size - 2] == 0) // how to check the bug.
-    {
-        char buf[128];
-        sprintf(buf, "Kernel Bug= wrong environments !  please, check "
-                     "/proc/%d/environ !",
-                pid);
-        size = strlen(buf) + 1;
-        if (file_size > size)
-            strcpy(envblock, buf);
-    }
-
     int i = 0, n = 0, v = 0;
     char ch;
 
@@ -2006,7 +1964,22 @@ Proc::Proc()
 
 Proc::~Proc()
 {
-    // killall procinfos
+    if(hprocs)
+    {
+        qDeleteAll(hprocs->begin(), hprocs->end());
+        hprocs->clear();
+    }
+    while (history.size() > 0)
+        delete history.takeFirst();
+
+    qDeleteAll(socks.begin(), socks.end());
+    socks.clear();
+
+    qDeleteAll(usocks.begin(), usocks.end());
+    usocks.clear();
+
+    qDeleteAll(categories.begin(), categories.end());
+    categories.clear();
 }
 
 // COMMON for LINUX,SOLARIS
@@ -2153,32 +2126,6 @@ void Procview::set_fields()
     fieldArrange();
 }
 
-// LINUX:
-// deduce whether the currently selected fields correspond to a field list
-void Procview::deduce_fields()
-{
-    return; // under development (by fasthyun@magicn.com) 2006/05/24
-
-    if (viewfields != CUSTOM)
-        return;
-
-    Procview::fieldstates tags[4] = {USER, JOBS, MEM, SCHED};
-    int *lists[4] = {basic_fields, jobs_fields, mem_fields, sched_fields};
-    for (int i = 0; i < 4; i++)
-    {
-        int *l = lists[i];
-        int j;
-        for (j = 0; l[j] != F_END; j++)
-            if (findCol(l[j]) < 0)
-                break;
-        if (l[j] == F_END && j == cats.size())
-        {
-            viewfields = tags[i];
-            return;
-        }
-    }
-}
-
 // move to Proc.cpp
 #include <sys/utsname.h> // uname()
 int get_kernel_version()
