@@ -100,7 +100,7 @@ enum fields
     F_STACK,
 #endif
     F_SIZE, // VSIZE
-    F_SWAP, // Linux not correct
+    F_SWAP,
     F_MEM,
     F_RSS,
 #ifdef LINUX
@@ -572,6 +572,7 @@ class Procinfo // Process Infomation
     unsigned long
         dt; // dirty pages (number of pages, not K), obsolute in Kernel 2.6
     unsigned long stack; // stack size (K)
+    unsigned long swap;  // swap size (K)
 #endif
 
 #ifdef SOLARIS
@@ -804,15 +805,14 @@ class Procview : public Proc
     void set_fields();
     void set_fields_list(int fields[]);
     void addField(char *name);                   // interface
-    void addField(int FIELD_ID, int where = -1); // base interface
+    int addField(int FIELD_ID, int where = -1); // base interface
     void removeField(int FIELD_ID);
     int findCol(int FIELD_ID);
     void moveColumn(int col, int place);
-    void deduce_fields();
     void fieldArrange();
     void update_customfield();
     //
-    void setSortColumn(int col, bool r = false);
+    void setSortColumn(int col, bool keepSortOrder = false);
     void setTreeMode(bool b);
     void saveCOMMANDFIELD();
 
