@@ -37,6 +37,7 @@ int flag_24_ok; // we presume a kernel 2.4.x
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <QString>
 
 // COMMON
 bool Procview::treeview = 0; // true
@@ -49,7 +50,7 @@ int Procview::mini_fields[] = {F_PID, F_STAT, F_MEM, F_CPU, F_CMDLINE, F_END};
 
 // COMMON?
 // return username from /etc/passwd
-char *userName(int uid, int euid)
+const QString userName(int uid, int euid)
 {
     char buff[128];
     struct passwd *pw = getpwuid(uid);
@@ -63,24 +64,19 @@ char *userName(int uid, int euid)
 
     if (uid != euid)
         strcat(buff, euid == 0 ? "*" : "+");
-
-    return strdup(buff);
+    return QString(buff);
 }
 
 // return group name (possibly numeric)
-char *groupName(int gid, int egid)
+const QString groupName(int gid, int egid)
 {
-    char *p;
+    QString res;
     struct group *gr = getgrgid(gid);
     if (!gr)
-    {
-        p = (char *)malloc(11);
-        sprintf(p, "%d", gid);
-    }
+        res = QString::number(gid);
     else
-        p = strdup(gr->gr_name);
-    //	s.append("*");
-    return p;
+        res = QString::fromLocal8Bit(gr->gr_name);
+    return res;
 }
 
 Category::~Category() {}
@@ -139,28 +135,15 @@ Cat_memory::Cat_memory(const QString &heading, const QString &explain, int w,
 QString Cat_memory::string(Procinfo *p)
 {
     QString s;
-    char buff[128];
-
-    long sizeK, sizeM;
-    sizeK = p->*uintl_member;
-
-    sizeM = sizeK / 1024;
-    /*	if ( sizeM > 1024 )
-            {
-                    sprintf(buff,"%dM",sizeM/1024);
-            }
-            else */
-    if (sizeM > 0)
-    {
-        sprintf(buff, "%ldM", sizeM);
-    }
+    long sizeK = p->*uintl_member;
+    double sizeM = static_cast<double>(sizeK) / 1024;
+    if (sizeM > 1.0)
+        s = QString::number(sizeM, 'f', 1) + QStringLiteral("M");
     else
-        sprintf(buff, "%ldK", sizeK);
+        s = QString::number(sizeK) + QStringLiteral("K");
 
     if (sizeK == 0)
-        s = "0";
-    else
-        s = buff;
+        s = QStringLiteral("0");
     return s;
 }
 
@@ -217,8 +200,11 @@ QString Cat_swap::string(Procinfo *p)
     // Possible with Linux ?
 
     long sizeK, sizeM;
+#ifdef LINUX
+    sizeK = p->swap;
+#else
     sizeK = p->size > p->resident ? p->size - p->resident : 0;
-
+#endif
     sizeM = sizeK / 1024;
 
     if (sizeM > 0)
@@ -377,12 +363,12 @@ Procview::Procview()
     cats.clear();
     reversed = false;
     viewproc = ALL;
-    treeview = true;
+    treeview = false;
     idxF_CMD = 0; // **** important ****
     viewfields = USER;
     set_fields();
 
-    sortcat = 0; // categories[F_PID];
+    sortcat = nullptr; // categories[F_PID];
     sort_column = -1;
     sortcat_linear = NULL;
     enable = true;
@@ -527,17 +513,13 @@ void Procview::set_fields_list(int fields[])
     cats.clear();
     for (int i = 0; fields[i] != F_END; i++)
     {
-        if (fields[i] == F_CPUNUM and Proc::num_cpus < 2)
-            continue; // not correctly work
+        if (fields[i] == F_CPUNUM && Proc::num_cpus < 2)
+            continue; // does not work correctly
 
-        Category *c = categories.value(fields[i], NULL);
+        Category *c = categories.value(fields[i], nullptr);
         if (c)
-        {
-            // printf("name=%s\n",c->name);
             cats.append(c);
-        }
     }
-    return;
 }
 
 // return the column number of a field, or -1 if not displayed
@@ -550,75 +532,72 @@ int Procview::findCol(int field_id)
 }
 
 // basis
+// returns the place where the field is added
+// (-1 if it already exists)
 // called by
 // 	void Procview::fieldArrange();
 // 	qps();
 //
-void Procview::addField(int Fid, int where)
+int Procview::addField(int Fid, int where)
 {
-    //	where=-1;
-    //	printf("Fid =%d where=%d\n",Fid,where);
-    //	where=pstable->clickedColumn();
-    if (where == 0)
-    {
-        // if (pstable->treeMode())  where=1;
-    }
-
-    if (Fid == F_PROCESSNAME)
-        where = 0;
-    if (Fid == F_CMDLINE)
-        where = cats.size(); // always should be the last column
-
-    if (where < 0)
+    if (where < 0 || where > cats.size())
     {
         // this is default
         where = cats.size();
     }
 
-    if (where > cats.size()) // CMD_LINE ! ??????
-        where = 1;
+    if (Fid == F_CMDLINE)
+        where = cats.size(); // always should be the last column
+    else if (Fid == F_PID)
+    {
+        if (treeview == true)
+            where = 0; // always should be the first column with the tree
+        else if (!cats.isEmpty() && where == cats.size()
+                 && cats[cats.size() - 1]->index == F_CMDLINE)
+        {
+            -- where;
+        }
+    }
+    else if (!cats.isEmpty())
+    {
+        if (where == cats.size())
+        {
+            if (cats[cats.size() - 1]->index == F_CMDLINE)
+              -- where;
+        }
+        else if (where == 0 && treeview == true && cats[0]->index == F_PID)
+            where = 1;
+    }
 
     Category *newcat = categories[Fid];
-    //	printf("name =%s where=%d\n",newcat->name,where);
-    if (cats.indexOf(newcat) < 0) // if not in the list ****
+    if (cats.indexOf(newcat) < 0) // if not in the list
+    {
         cats.insert(where, newcat);
+        return where;
+    }
+    return -1; // nothings is added
 }
 
 // add a category to last by name
-void Procview::addField(char *name) // interface
+void Procview::addField(char *name)
 {
-    // QString str=sl[i];
     int id = field_id_by_name(name);
     if (id >= 0)
         addField(id); // add to last
-
-    return;
-
-    Category *cat = cat_by_name(name);
-    if (cat)
-        cats.append(cat);
 }
 
 void Procview::removeField(int field_id)
 {
     for (int i = 0; i < cats.size();)
     {
-        //	 	printf("Fid=%d cats[%d].id=%d
-        //\n",field_id,i,cats[i]->id);
-        if (true)
+        if (cats[i]->id == field_id)
         {
-            if (cats[i]->id == field_id)
-            {
-                //	if(cats[i]->id==F_CMD and !treeview)
-                // idxF_CMD=-1;
-                cats.remove(i);
-                break;
-            }
-            else
-                i++;
+            cats.remove(i);
+            break;
         }
+        else
+            i++;
     }
-    //	printf("Fid=%d cats.size=%d\n",field_id,cats.size());
 }
 
 //	called by
@@ -657,40 +636,33 @@ void Procview::update_customfield()
 //				  From col To place
 void Procview::moveColumn(int col, int place)
 {
-    int i;
-
-    int f_size = cats.size();
-    if (col < 0 or place < 0 or f_size <= col or f_size <= place)
+    int s = cats.size();
+    if (col < 0 || place < 0 || s <= col || s <= place)
     {
         printf("QPS code bugs!! : moveColumn() col=%d place=%d "
                "cats.size=%d\n",
-               col, place, cats.size());
+               col, place, s);
         return;
     }
+    if (col == place)
+        return;
 
-    if (treeview == true)
-    {
-        // *** important : F_PROCESSNAME field should be the first in
-        // TreeMode!
-        /// if(place==0)	return;
-        if (cats[col]->index == F_PROCESSNAME)
+    if (cats[col]->index == F_PID)
+    { // PID should always be the first field in the tree model
+        if (treeview == true)
             place = 0;
     }
+    else if (cats[col]->index == F_CMDLINE)
+        place = s; // COMMAND_LINE should always be the last field
 
-    // COMMAND_LINE field should always be the last field
-    // if(cats[place]->index==F_CMDLINE) return;
-    if (cats[col]->index == F_CMDLINE)
-        place = cats.size() - 1;
-
-    Category *cat = cats[col]; // SEGFAULT POSSIBLE!
-    cats.insert(place, cat);   // insert
-
+    // first insert it into the new place; then remove it from the old one
+    Category *cat = cats[col];
     if (place < col)
-        col++;
-
-    cats.remove(col); // remove idx
-                      // refresh();
-                      /// update_customfield();
+        ++col;
+    else// if (place > col)
+        place = qMin(place + 1, s);
+    cats.insert(place, cat);
+    cats.remove(col);
 }
 
 // always called when linear to tree
@@ -704,49 +676,34 @@ void Procview::saveCOMMANDFIELD() {}
 //	TODO: checkField();
 void Procview::fieldArrange()
 {
+    int s = cats.size();
 
-    if (treeview == true)
+    // PID should always be the first field in the tree model
+    if (treeview == true && cats[0]->index != F_PID)
     {
-        // 	Tree Mode
-        // 	If ProcessName isn't the leftmost column, move it to
-        // leftmost
-        // *** important : F_PROCESSNAME field should be the first in
-        // TreeMode!
-        if (cats[0]->index != F_PROCESSNAME)
+        bool found = false;
+        for (int i = 1; i < s; i++)
         {
-            // find F_PROCESSNAME
-            for (int i = 1; i < cats.size(); i++)
+            if (cats[i]->index == F_PID)
             {
-                if (cats[i]->index == F_PROCESSNAME)
-                    moveColumn(i, 0);
+                found = true;
+                moveColumn(i, 0);
+                break;
             }
         }
-        // PID sort for convenience (default)
-        /*
-        if(false and cats[i]->index == F_PID )
-        {
-                reversed = false;
-                sortcat = cats[i];
-                //// pstable->setSortedCol(i);
-        }	*/
-        // Linear_Mode:
+        if (!found)
+            addField(F_PID, 0);
     }
 
-    if (true)
+    // COMMAND_LINE should always be the last field
+    if (cats[s - 1]->index != F_CMDLINE)
     {
-
-        for (int i = 0; i < cats.size(); i++)
+        for (int i = 0; i < s - 1; i++)
         {
-
             if (cats[i]->index == F_CMDLINE)
             {
-                // COMMAND_LINE field should always be the last
-                // field
-                if (i == (cats.size() - 1))
-                    moveColumn(i, 0);
-                else
-                {
-                }
+                moveColumn(i, 0); // will go to the end; see Procview::moveColumn
+                break;
             }
         }
     }
@@ -763,20 +720,26 @@ void Procview::setTreeMode(bool b)
     }
 }
 
-void Procview::setSortColumn(int col, bool r)
+void Procview::setSortColumn(int col, bool keepSortOrder)
 {
-    // qDebug("xxx error? col>=cats.size() %d",col);
-    if (col >= cats.size())
+    if (col < 0 || col >= cats.size()) // restore defaults
     {
-        qDebug("hmmm error? col>=cats.size() %d", col);
+        if (col >= 0)
+            qDebug("hmmm error? col>=cats.size() %d", col);
+        sort_column = -1;
+        sortcat = nullptr;
+        reversed = false;
         return;
     }
 
-    // if(!procview->treeview) just reverse the lines
-    if (col == sort_column)
-        reversed = !reversed;
-    else
-        reversed = false;
+    // if(!procview->treeview) ?
+    if (!keepSortOrder)
+    {
+        if (col == sort_column)
+            reversed = !reversed;
+        else
+            reversed = false;
+    }
     sortcat = cats[col];
     sort_column = col;
 }
@@ -841,22 +804,11 @@ int Proc::field_id_by_name(const QString &s)
 // postInit
 void Proc::commonPostInit()
 {
-    // java style
-    /*
-    QHashIterator<int,Category *> i(categories);  // a little suck!
-    while (i.hasNext()) {
-                    i.next();
-                    i.value()->index=i.key();
-                    i.value()->id=i.key();
-    }*/
-
-    // STL style , set id
     QHash<int, Category *>::iterator i = categories.begin();
     while (i != categories.end())
     {
         i.value()->index = i.key();
         i.value()->id = i.key();
-        // cout << i.key() << ": " << i.value() << endl;
         ++i;
     }
 
@@ -878,7 +830,6 @@ void Proc::commonPostInit()
 
     Proc::mem_buffers = 0;
     Proc::mem_cached = 0;
-    // mem_shared = 0; // only linux kernel 2.4.x???
 
     Proc::swap_total = 0;
     Proc::swap_free = 0;
@@ -1007,6 +958,12 @@ void Proc::refresh()
     SysHistory *s = new SysHistory;
 
     history.append(s);
+
+    if(hprocs)
+    {
+        qDeleteAll(hprocs->begin(), hprocs->end());
+        hprocs->clear();
+    }
     hprocs = &(s->procs);
 
     // init
