@@ -69,43 +69,6 @@ void Pstable::set_sortcol()
     setSortedCol(-1);
 }
 
-// for Optimization
-int Pstable::sizeHintForColumn(int col) const
-{
-    // int aw=fontMetrics().averageCharWidth();
-    int aw = fontMetrics().width("0");
-    int cat_idx = procview->cats[col]->index;
-    // if(col==0) printf("col.idx=%d
-    // %s\n",cat_idx,procview->cats[col]->name);
-    switch (cat_idx)
-    {
-    // 	only COMMON Field
-    //		case F_PID :
-    case F_RSS:
-    case F_SIZE:
-    case F_TTY:
-        return aw * 6;
-    case F_MEM:
-    case F_START:
-    case F_CPU: // PCPU
-        return aw * 6 + 2;
-    case F_TIME:
-        return aw * 5;
-    case F_WCPU:
-    case F_NICE:
-        return aw * 5;
-    case F_CMD:
-        return -(aw * 20);
-
-    case F_USER:
-    //		case F_USER : return aw*10;
-    case F_CMDLINE:
-    default:
-        return -1;
-    }
-    return -1;
-}
-
 // inner
 QString Pstable::title(int col)
 {
@@ -117,6 +80,17 @@ QString Pstable::title(int col)
     return procview->cats[col]->name;
 }
 
+QString Pstable::dragTitle(int col)
+{
+    if (col >= procview->cats.size()
+        || procview->cats[col]->index == F_CMDLINE
+        || (procview->cats[col]->index == F_PID && procview->treeview))
+    {
+        return ""; // not movable
+    }
+    return procview->cats[col]->name;
+}
+
 // TESTING
 void Pstable::overpaintCell(QPainter *p, int row, int col, int xpos)
 {
@@ -399,11 +373,7 @@ char *Pstable::total_selectedRow(int col)
 Pstable::Pstable(QWidget *parent, Procview *pv) : HeadedTable(parent, 0)
 {
     procview = pv;
-    //	connect(this, SIGNAL(selectionChanged(const Svec<int>
-    //*)),SLOT(selection_update(const Svec<int> *))); //DEL?
-    //	connect(this,
-    // SIGNAL(selectionChanged()),SLOT(selection_update())); //
-    // when procinfo clicked
+
     connect(this, SIGNAL(titleClicked(int)), SLOT(setSortColumn(int)));
     connect(this, SIGNAL(foldSubTree(int)), SLOT(subtree_folded(int)));
     connect(head, SIGNAL(toolTip(QPoint, int)), this,
@@ -412,8 +382,10 @@ Pstable::Pstable(QWidget *parent, Procview *pv) : HeadedTable(parent, 0)
     connect(this, SIGNAL(outOfCell()), SLOT(mouseOutOfCell()));
 }
 
-// who call this ? : from qps.cpp
-void Pstable::setProcview(Procview *pv) { procview = pv; }
+void Pstable::setReveseSort(bool reverse)
+{
+    head->setReveseSort(reverse);
+}
 
 HeadedTable::NodeState Pstable::folded(int row)
 {
@@ -464,14 +436,11 @@ uses
 // 	slot: changes table mode
 void Pstable::setTreeMode(bool treemode)
 {
-    // qDebug("Pstable::setTreeMode() %d , procview.treeview
-    // =%d\n",treemode,procview->treeview);
-    // no more HeadedTable::setTreeMode(treemode);
     HeadedTable::setTreeMode(treemode);
     procview->treeview = treemode;
     procview->fieldArrange();
     set_sortcol();
-    refresh(); //==rebuild();
+    refresh();
 }
 
 //
@@ -493,14 +462,11 @@ bool Pstable::columnMovable(int col)
 //	virtual HeadedTable::moveCol(col,place);
 void Pstable::moveCol(int col, int place)
 {
-    // qDebug("Pstable::moveCol\n");
     procview->moveColumn(col, place);
-    set_sortcol(); //???
     procview->fieldArrange();
-    //	update();
+    set_sortcol();
     refresh(); // width size changed ,...
     return;
-    // updateColWidth(place); updateColWidth(col);// TEMP
 }
 
 // NEED Check !!
@@ -526,9 +492,7 @@ void Pstable::subtree_folded(int row)
         int r = row + 1;
         while (r < numRows() && procview->linear_procs[r] != nextp)
             r++;
-        //	setAutoUpdate(FALSE);
         showRange(row, r - 1);
-        // setAutoUpdate(TRUE);
     }
     // This is a stopgap solution; it would be better to have htable
     // take care of the hiding of subtrees and repaint only the rows under
@@ -558,8 +522,6 @@ void Pstable::checkTableModel()
         //		printf("Warnning: maybe this is the bug.. wrong!
         //%d
         //%d\n",kgen,procview->current_gen);
-        //		setAutoUpdate(false);  // ********** important for
-        // GUI-thread
         //		HeadedTable::setTreeMode(procview->treeview);
         procview->rebuild();                       // for Table
         setNumRows(procview->linear_procs.size()); // 1.
@@ -567,7 +529,6 @@ void Pstable::checkTableModel()
         //=%d\n",treemode,procview->treeview);
         setNumCols(procview->cats.size()); // 2. resetWidths()
         kgen = procview->current_gen;
-        //		setAutoUpdate(true);
     }
 }
 
@@ -575,29 +536,11 @@ void Pstable::checkTableModel()
 
 void Pstable::refresh()
 {
-    //    qDebug("Pstable:refresh()");
-    //	procview->refresh(); -> move to Qps::refresh()
-    //	qDebug("catsize=%d\n",procview->cats.size());
     procview->rebuild();                       // for Table
     setNumRows(procview->linear_procs.size()); // 1.
     setNumCols(procview->cats.size());         // 2. resetWidths()  UNINITIAL
     kgen = procview->current_gen;
-    // checkTableModel();
     repaint_changed();
 
-    /*
-    if(true)
-    {
-            int count=0,trow=0;
-            for(int row = 0; row < nrows; row++)
-                    if(isSelected(row))
-                    {
-                            count++;
-                            trow=row;
-                    }
-            if (count == 1)
-                    centerVertically(trow);
-    } */
-
     STATUSBAR_SETCOUNT(procview->num_process);
 }
