@@ -33,7 +33,6 @@ class Pstable : public HeadedTable
     Pstable(QWidget *parent, Procview *pv);
 
     void set_sortcol();
-    void setProcview(Procview *pv);
     virtual void moveCol(int col, int place);
     void refresh();
 
@@ -44,6 +43,7 @@ class Pstable : public HeadedTable
     virtual void setSelected(int row, bool sel);
     virtual int totalRow();
     virtual void checkTableModel();
+    void setReveseSort(bool reverse);
 
   public slots:
     // void selection_update(const Svec<int> *row);
@@ -57,6 +57,7 @@ class Pstable : public HeadedTable
   protected:
     // implementation of the interface to HeadedTable
     virtual QString title(int col);
+    virtual QString dragTitle(int col);
     virtual QString text(int row, int col);
     virtual int colWidth(int col);
     virtual int alignment(int col);
@@ -66,7 +67,6 @@ class Pstable : public HeadedTable
     virtual int parentRow(int row);
     virtual bool lastChild(int row);
     virtual char *total_selectedRow(int col);
-    virtual int sizeHintForColumn(int col) const;
     virtual bool columnMovable(int col);
 
     virtual void overpaintCell(QPainter *p, int row, int col, int xpos);
