@@ -47,7 +47,7 @@ enum ScrollBarDirtyFlags
     horMask = 0xF0
 };
 
-QtTableView::QtTableView(QWidget *parent, const char *name)
+QtTableView::QtTableView(QWidget *parent, const char* /*name*/)
     : QAbstractScrollArea(parent)
 {
     nRows = nCols = 0; // zero rows/cols
@@ -56,7 +56,6 @@ QtTableView::QtTableView(QWidget *parent, const char *name)
     xCellDelta = yCellDelta = 0; // zero cell offset
     xOffs = yOffs = 0;           // zero total pixel offset
     cellH = cellW = 0;           // user defined cell size
-    vScrollBar = hScrollBar = 0; // no scroll bars
     tFlags = 0;
     sbDirty = 0;
     verSliding = false;
@@ -66,80 +65,32 @@ QtTableView::QtTableView(QWidget *parent, const char *name)
     inSbUpdate = false;
     flag_view = 0;
     view = viewport();
-    enablePaint = true;
     test = false;
 
-    // setSizePolicy(QSizePolicy
-    // (QSizePolicy::Expanding,QSizePolicy::Expanding));
-    // setFocusPolicy(Qt::NoFocus);
-
-    verticalScrollBar();   // created
-    horizontalScrollBar(); // created
-                           //	setFocusPolicy(Qt::NoFocus);
-                           //	setFrameShape (QFrame::NoFrame);
-                           //	setStyle(new QCleanlooksStyle); // compiz bug
-                           //	setStyle(new QWindowsStyle); // repaint bug
+    QScrollBar *sb = verticalScrollBar();
+    if (sb)
+    {
+        connect(sb, SIGNAL(valueChanged(int)), SLOT(verSbValue(int)));
+        connect(sb, SIGNAL(sliderMoved(int)), SLOT(verSbSliding(int)));
+        connect(sb, SIGNAL(sliderReleased()), SLOT(verSbSlidingDone()));
+    }
+    sb = horizontalScrollBar();
+    if (sb)
+    {
+        connect(sb, SIGNAL(valueChanged(int)), SLOT(horSbValue(int)));
+        connect(sb, SIGNAL(sliderMoved(int)), SLOT(horSbSliding(int)));
+        connect(sb, SIGNAL(sliderReleased()), SLOT(horSbSlidingDone()));
+    }
 }
 /*
   Destroys the table view.
 */
 QtTableView::~QtTableView()
 {
-    delete vScrollBar;
-    delete hScrollBar;
 }
 
-/*
-  Returns a pointer to the vertical scroll bar mainly so you can
-  connect() to its signals.  Note that the scroll bar works in pixel
-  values; use findRow() to translate to cell numbers.
-*/
-
-QScrollBar *QtTableView::verticalScrollBar() const
-{
-    QtTableView *that = (QtTableView *)this; // semantic const
-    if (!vScrollBar)
-    {
-        QScrollBar *sb = QAbstractScrollArea::verticalScrollBar();
-        sb->setFocusPolicy(Qt::NoFocus);
-        connect(sb, SIGNAL(valueChanged(int)), SLOT(verSbValue(int)));
-        connect(sb, SIGNAL(sliderMoved(int)), SLOT(verSbSliding(int)));
-        connect(sb, SIGNAL(sliderReleased()), SLOT(verSbSlidingDone()));
-        that->vScrollBar = sb;
-        // vScrollBar = sb;
-        return sb;
-    }
-    return vScrollBar;
-}
-
-QScrollBar *QtTableView::horizontalScrollBar() const
-{
-    QtTableView *that = (QtTableView *)this; // semantic const
-    if (!hScrollBar)
-    {
-        QScrollBar *sb = QAbstractScrollArea::horizontalScrollBar();
-        sb->setFocusPolicy(Qt::NoFocus);
-        //	sb->setTracking( true ); // bar cause heads moving
-        connect(sb, SIGNAL(valueChanged(int)), SLOT(horSbValue(int)));
-        connect(sb, SIGNAL(sliderMoved(int)), SLOT(horSbSliding(int)));
-        connect(sb, SIGNAL(sliderReleased()), SLOT(horSbSlidingDone()));
-        that->hScrollBar = sb;
-        return sb;
-    }
-    return hScrollBar;
-}
-
-/*
-  Sets the number of rows of the table to \a rows (must be non-negative).
-  Does not change topCell().
-  The table repaints itself automatically if updatesEnabled() is set.
-
-  numCols(), setNumCols(), numRows()
-*/
-
 void QtTableView::setNumRows(int rows)
 {
-    ///	view->setMaximumHeight(rows*cellH);
     if (rows < 0)
     {
         qWarning("QtTableView::setNumRows: (%s) Negative argument %d.",
@@ -149,13 +100,8 @@ void QtTableView::setNumRows(int rows)
     if (nRows == rows)
         return;
 
-    if (isVisible())
-    {
-        int oldLastVisible = lastRowVisible();
-        int oldTopCell = topCell();
-    }
     nRows = rows;
-    updateScrollBars(verRange);
+    //updateScrollBars(verRange); // not needed; see HeadedTable::setNumCols()
 }
 
 void QtTableView::setNumCols(int cols)
@@ -168,9 +114,9 @@ void QtTableView::setNumCols(int cols)
     }
     if (nCols == cols)
         return;
-    int oldCols = nCols;
+
     nCols = cols;
-    updateScrollBars(horRange); // int maxCol = lastColVisible();
+    //updateScrollBars(horRange); // not needed; see HeadedTable::setNumCols()
 }
 
 /*
@@ -296,12 +242,14 @@ void QtTableView::setYOffset(int y) { setOffset(xOffset(), y, true); }
   \sa xOffset(), yOffset(), setXOffset(), setYOffset(), setTopLeftCell()
 */
 
-void QtTableView::setOffset(int x, int y, bool updateScrBars)
+void QtTableView::setOffset(int x, int y, bool updateScrBars, bool scroll)
 {
     if ((!testTableFlags(Tbl_snapToHGrid) || xCellDelta == 0) &&
         (!testTableFlags(Tbl_snapToVGrid) || yCellDelta == 0) &&
         (x == xOffs && y == yOffs))
+    {
         return;
+    }
 
     if (x < 0)
         x = 0;
@@ -331,7 +279,7 @@ void QtTableView::setOffset(int x, int y, bool updateScrBars)
             xn += xcd;
             col++;
         }
-        xCellOffs = col; //!!!
+        xCellOffs = col;
         if (testTableFlags(Tbl_snapToHGrid))
         {
             xCellDelta = 0;
@@ -346,7 +294,7 @@ void QtTableView::setOffset(int x, int y, bool updateScrBars)
     { // same cellHegiht
         if (y > maxYOffset())
             y = maxYOffset();
-        yCellOffs = y / cellH; //********
+        yCellOffs = y / cellH;
         if (!testTableFlags(Tbl_snapToVGrid))
         {
             yCellDelta = (short)(y % cellH);
@@ -357,18 +305,13 @@ void QtTableView::setOffset(int x, int y, bool updateScrBars)
             yCellDelta = 0;
         }
     }
-    else
-    {
-    }
-    //	printf("y=%d yOffs=%d ", y,yOffs);
+
     int dx = (xOffs - x);
-    int dy = (yOffs - y); //
+    int dy = (yOffs - y);
     xOffs = x;
     yOffs = y;
-    if (updatesEnabled() && isVisible())
+    if (scroll && updatesEnabled() && isVisible())
     {
-        // *** scroll() call update( desposal region ) !!
-        // printf("scroll: xpixel=%d , ypixel=%d \n",xPixels,yPixels);
         scrollTrigger(dx, dy);
         view->scroll(dx, dy);
     }
@@ -376,11 +319,6 @@ void QtTableView::setOffset(int x, int y, bool updateScrBars)
         updateScrollBars(verValue | horValue);
 }
 
-void QtTableView::scrollContentsBy(int dx, int dy)
-{
-    // view->update() //default
-    // printf("scroll: dx=%d , dy=%d \n",dx,dy);
-}
 /*
   Moves the visible area of the table right by \a xPixels and
   down by \a yPixels pixels.  Both may be negative.
@@ -398,11 +336,11 @@ void QtTableView::scrollContentsBy(int dx, int dy)
   \sa setCellWidth(), cellHeight()
   Returns the width of column \a col in pixels.
 
-  setCellWidth(), cellHeight(), totalWidth(), updateTableSize()
+  setCellWidth(), cellHeight(), totalWidth(), updateOffsets()
 */
 
 // virtual
-int QtTableView::cellWidth(int col) { return cellW; }
+int QtTableView::cellWidth(int /*col*/) const { return cellW; }
 
 /*
   Sets the width in pixels of the table cells to \a cellWidth.
@@ -446,12 +384,12 @@ void QtTableView::setCellWidth(int cellWidth)
 
   This function is virtual and must be reimplemented by subclasses that
   have variable cell heights.  Note that if the total table height
-  changes, updateTableSize() must be called.
+  changes, updateOffsets() must be called.
 
   \sa setCellHeight(), cellWidth(), totalHeight()
 */
 
-int QtTableView::cellHeight(int) { return cellH; }
+int QtTableView::cellHeight(int) const { return cellH; }
 
 /*
   Sets the height in pixels of the table cells to \a cellHeight.
@@ -598,7 +536,6 @@ void QtTableView::setTableFlags(uint f)
     tFlags |= f;
 
     bool updateOn = updatesEnabled();
-    setAutoUpdate(false);
 
     uint repaintMask = Tbl_cutCellsV | Tbl_cutCellsH;
 
@@ -638,7 +575,6 @@ void QtTableView::setTableFlags(uint f)
 
     if (updateOn)
     {
-        setAutoUpdate(true);
         updateScrollBars();
         if (isVisible() && (f & repaintMask))
             update();
@@ -665,7 +601,6 @@ void QtTableView::clearTableFlags(uint f)
     tFlags &= ~f;
 
     bool updateOn = updatesEnabled();
-    setAutoUpdate(false);
 
     uint repaintMask = Tbl_cutCellsV | Tbl_cutCellsH;
 
@@ -708,41 +643,12 @@ void QtTableView::clearTableFlags(uint f)
     }
     if (updateOn)
     {
-        setAutoUpdate(true);
         updateScrollBars(); // returns immediately if nothing to do
         if (isVisible() && (f & repaintMask))
             update(); // repaint();
     }
 }
 
-/*
-  Sets the auto-update option of the table view to  enable.
-
-  If enable is true (this is the default), the view updates itself
-  automatically whenever it has changed in some way (for example, when a
-  setTableFlags() flag\endlink is changed).
-*/
-
-void QtTableView::setAutoUpdate(bool enable)
-{
-    enablePaint = enable;
-    // updatesEnabled= enable ;
-
-    // setAttribute(Qt::WA_ForceUpdatesDisabled, !enable);
-    ////    setAttribute(Qt::WA_UpdatesDisabled, !enable);
-    //     d->setUpdatesEnabled_helper(enable);
-
-    return;
-
-    if (updatesEnabled() == enable)
-        return;
-    setUpdatesEnabled(enable); // update() call
-    if (enable)
-    {
-        //  updateScrollBars();
-    }
-}
-
 /*
   Returns the index of the last (bottom) row in the view.
   The index of the first row is 0.
@@ -885,8 +791,8 @@ void QtTableView::horSbSliding(int val)
 
 void QtTableView::horSbSlidingDone()
 {
-    if (testTableFlags(Tbl_snapToHGrid) && testTableFlags(Tbl_smoothHScrolling))
-        ; //	snapToGrid( true,  false );
+    //if (testTableFlags(Tbl_snapToHGrid) && testTableFlags(Tbl_smoothHScrolling))
+        //; //	snapToGrid( true,  false );
 }
 
 /*
@@ -942,8 +848,8 @@ void QtTableView::verSbSliding(int val)
 
 void QtTableView::verSbSlidingDone()
 {
-    if (testTableFlags(Tbl_snapToVGrid) && testTableFlags(Tbl_smoothVScrolling))
-        ; // snapToGrid(  false, true );
+    //if (testTableFlags(Tbl_snapToVGrid) && testTableFlags(Tbl_smoothVScrolling))
+        //; // snapToGrid(  false, true );
 }
 
 /*
@@ -958,10 +864,8 @@ void QtTableView::verSbSlidingDone()
   Calls paintCell() for the cells that needs to be repainted.
 */
 // work?
-void QtTableView::repaintCell(int row, int col, bool usecache) // false
+void QtTableView::repaintCell(int row, int col, bool /*usecache*/) // false
 {
-    //
-    static int c = 0;
     int xPos, yPos;
     if (!colXPos(col, &xPos))
         return;
@@ -969,10 +873,7 @@ void QtTableView::repaintCell(int row, int col, bool usecache) // false
         return;
 
     QRect uR = QRect(xPos, yPos, cellWidth(col), cellHeight(row));
-    // printf("repaintCell() %d,
-    // [%d,%d,%d,%d]\n",c++,uR.x(),uR.y(),uR.width(),uR.height() );
     view->repaint(uR.intersected(viewRect())); // slow
-    // view->update( uR.intersect(viewRect()));
 }
 
 // using
@@ -980,57 +881,21 @@ void QtTableView::repaintRow(int row)
 {
     int y;
     if (rowYPos(row, &y))
-    {
-        // view->repaint(minViewX(),y,viewWidth(),cellHeight());
         view->update(minViewX(), y, viewWidth(), cellHeight());
-    };
 }
 
 extern QThread *thread_main;
 void QtTableView::paintEvent(QPaintEvent *e)
 {
-    static int count = 0;
-
-    ////if(thread_main!=thread())
-    ///	printf("Error : main_thread(%X) != paint_thread(%X) report this
-    /// message!!!\n",thread_main,thread());
-
-    /// if ( !isVisible() or !enablePaint )	return;
     checkProfile(); // check cache, current_get
 
     if (!isVisible())
         return;
 
     QRect viewR = viewRect();
-    bool flag_fullpainting = false;
     QRect updateR = e->rect(); // update rectangle
 
-    QPainter paint(viewport());
-    //	printf("Qps: %s::paintEvent()
-    // count=%d\n",objectName().toAscii().data(),count++);
-    //	printf("%s
-    //[%d,%d,%d,%d];\n",objectName().toAscii().data(),updateR.x(),updateR.y(),updateR.width(),updateR.height());
-
-    /*  possible?
-            int maxVX = maxXOffset(), maxVY = maxYOffset();
-            if ( updateR.right() > maxVX )	updateR.setRight( maxVX );
-            if ( updateR.bottom() > maxVY ) updateR.setBottom( maxVY );
-    */
-
-    if (updateR.width() < viewR.width() or updateR.height() < viewR.height())
-    {
-        // when: Scroll_up,down and Selection
-        // printf("partial: %d!=%d,
-        // %d!=%d\n",updateR.width(),viewR.width(),updateR.height(),viewR.height());
-        // printf("viewR (%d,%d,%d,%d)
-        // \n",viewR.x(),viewR.y(),viewR.width(),viewR.height());
-    }
-    else
-    {
-        flag_fullpainting = true;
-        ///	printf("%s::paintEvent() fullpainting
-        ///%d\n",objectName().toAscii().data(),count++);
-    }
+    QPainter p(viewport());
 
     int firstRow = findRow(updateR.y());
     int firstCol = findCol(updateR.x());
@@ -1040,18 +905,14 @@ void QtTableView::paintEvent(QPaintEvent *e)
     if (!colXPos(firstCol, &xStart))
     {
         // right empty area of table
-        // paint.eraseRect( updateR ); // erase area outside cells but
-        // in view
-        // printf("colXPos null\n");
-        eraseRight(&paint, updateR);
+        // p.eraseRect( updateR ); // erase area outside cells but in view
+        eraseRight(&p, updateR);
         return;
     }
 
-    // if ( !rowYPos( firstRow, &yStart ) || !colXPos( firstCol, &xStart ) )
     if (!rowYPos(firstRow, &yStart))
     { // get firstRow
-        // printf("eraseRect()\n");
-        paint.eraseRect(updateR);
+        p.eraseRect(updateR);
         return;
     }
 
@@ -1061,52 +922,31 @@ void QtTableView::paintEvent(QPaintEvent *e)
     int col;
     int yPos = yStart;
     int xPos = maxX + 1; // in case the while() is empty
-    int nextX;
-    int nextY;
 
-    // printf("frow=%d,fcol=%d\n",firstRow,firstCol);
-    // void 	(QtTableView::*painT)( QPainter *, int row, int col
-    // ,bool
-    // update);
-    // painT=&QtTableView::paintCell;
-    // paint.setClipRect( 0,0,viewR.width()-30,viewR.height() ); //enable,
-    // font
-    // not clip
+    p.setClipRect(viewR); // enable, font not clip (less Qt-4.3.x)
 
-    paint.setClipRect(viewR); // enable, font not clip (less Qt-4.3.x)
-    // paint.setClipRect(updateR); //enable, font not clip
-
-    while (yPos <= maxY and row < nRows)
+    while (yPos <= maxY && row < nRows)
     { // row=...5,6,7....
-        nextY = yPos + cellHeight();
         col = firstCol;
         xPos = xStart;
-        while (xPos < maxX and col < nCols)
+        while (xPos < maxX && col < nCols)
         {
             QRect cell;
             int width = cellWidth(col);
-            nextX = xPos + width;
             cell.setRect(xPos, yPos, width, cellH);
             tmp_size = viewR.intersected(cell).size();
-            tmp_x = xPos;
-            {
-                paint.translate(xPos, yPos); // (0,0) 	// for subclass
-                //(*this.*painT)( &paint, row, col ,
-                // flag_use_cache);
-                paintCell(&paint, row, col, false);
-                paint.translate(-xPos, -yPos); // paint.translate(0,0);
-            }
+
+            p.translate(xPos, yPos); // (0,0) 	// for subclass
+            paintCell(&p, row, col);
+            p.translate(-xPos, -yPos); // p.translate(0,0);
+
             col++;
-            xPos = nextX;
+            xPos += width;
         }
         row++;
-        yPos = nextY;
+        yPos += cellHeight();
     }
 
-    //	printf("%s: xoff=%d ,yoff=%d
-    //\n",objectName().toAscii().data(),xOffs,
-    // yOffs);
-
     // while painting we have to erase any areas in the view that
     // are not covered by cells but are covered by the paint event
     // rectangle these must be erased. We know that xPos is the last
@@ -1116,42 +956,26 @@ void QtTableView::paintEvent(QPaintEvent *e)
         QRect r = viewR;
         r.setLeft(xPos);
         r.setBottom(yPos < maxY ? yPos : maxY);
-
         // QRect ir=r.intersect( updateR );
-        eraseRight(&paint, r); //????????
+        eraseRight(&p, r);
     }
 
     if (yPos <= maxY)
     {
         QRect r = viewR;
         r.setTop(yPos);
-        paint.eraseRect(r.intersected(updateR));
+        p.eraseRect(r.intersected(updateR));
     }
 }
 
 void QtTableView::repaintChanged() // only fullpainting
 {
-
-    if (0)
-    {
-        //	printf("repaintChanged()\n");
-        test = true;
-        //	viewport()->setAutoFillBackground (false);
-        viewport()->setAttribute(Qt::WA_OpaquePaintEvent);
-        viewport()->repaint();
-        viewport()->setAttribute(Qt::WA_OpaquePaintEvent, false);
-        test = false;
-    }
-
     if (!isVisible())
         return;
-    bool flag_fullpainting = false;
 
     QRect updateR = viewRect();
     QRect viewR = viewRect();
 
-    flag_fullpainting = true;
-
     int firstRow = findRow(updateR.y());
     int firstCol = findCol(updateR.x());
 
@@ -1160,15 +984,12 @@ void QtTableView::repaintChanged() // only fullpainting
     if (!colXPos(firstCol, &xStart))
     {
         // right empty area of table
-        printf("b\n");
         view->update(updateR);
         return;
     }
 
-    // if ( !rowYPos( firstRow, &yStart ) || !colXPos( firstCol, &xStart ) )
     if (!rowYPos(firstRow, &yStart))
     { // get firstRow
-        /// printf("a\n");
         view->update(updateR);
         return;
     }
@@ -1193,7 +1014,6 @@ void QtTableView::repaintChanged() // only fullpainting
             int width = cellWidth(col);
             nextX = xPos + width;
             cell.setRect(xPos, yPos, width, cellH);
-            int ctl = 0;
             tmp_size = viewR.intersected(cell).size();
 
             if (isCellChanged(row, col))
@@ -1201,12 +1021,9 @@ void QtTableView::repaintChanged() // only fullpainting
                 if (col == firstCol)
                 {
                     repaintRow(row); //  speed up!  update()...
-                    //	view->update(minViewX(),y,viewWidth(),cellHeight());
-                    ///	printf("row %d\n",row);
                     break;
                 }
 
-                // printf("row %d col=%d\n",row,col);
                 repaintCell(row, col, false);
             }
             col++;
@@ -1229,39 +1046,12 @@ void QtTableView::repaintChanged() // only fullpainting
         r.setTop(yPos);
         view->repaint(r.intersected(updateR)); // why? CPU +2~3% -> rect.unite()
     }
-
-    return;
-
-    int rows = numRows();
-    int cols = numCols();
-    int left = leftCell(), right = lastColVisible();
-    int top = topCell(), bottom = lastRowVisible();
-
-    if (right >= cols)
-        right = cols - 1; //???
-    if (bottom >= rows)
-        bottom = rows - 1;
-    // if width[col] be changed ,then the right of [col] should be repainted
-    // !
-    // repaintColumns(c,-1);
-    // printf("left=%d \n",left);
-
-    for (int r = top; r <= bottom; r++)
-    {
-        for (int c = left; c <= right; c++)
-        {
-            // if(isCellChanged(r,c)) 	repaintCell(r, c,false);
-        }
-    }
 }
 
 void QtTableView::resizeEvent(QResizeEvent *e)
 {
-    //    printf("QtTableView::resize [%d,%d] \n",width(),height());
-    // QAbstractScrollArea::resizeEvent(e);
-    updateScrollBars(horValue | verValue | horSteps | horRange | verSteps |
-                     verRange);
-    return;
+    QAbstractScrollArea::resizeEvent(e);
+    updateScrollBars();
 }
 
 // BOTTLENECK?
@@ -1270,7 +1060,13 @@ int QtTableView::findRawRow(int yPos, int *cellMaxY, int *cellMinY,
 {
     int r = -1;
     if (nRows == 0)
+    {
+        if (cellMaxY)
+            *cellMaxY = 0;
+        if (cellMinY)
+            *cellMinY = 0;
         return r;
+    }
     if (goOutsideView || (yPos >= minViewY() && yPos <= maxViewY()))
     {
         if (yPos < minViewY())
@@ -1281,6 +1077,10 @@ int QtTableView::findRawRow(int yPos, int *cellMaxY, int *cellMinY,
                      "not supported. (%d,%d)",
                      name("unnamed"), yPos, yOffs);
 #endif
+            if (cellMaxY)
+                *cellMaxY = 0;
+            if (cellMinY)
+                *cellMinY = 0;
             return -1;
         }
         if (cellH)
@@ -1294,15 +1094,14 @@ int QtTableView::findRawRow(int yPos, int *cellMaxY, int *cellMinY,
         }
         else
         { // variable cell height
-            QtTableView *tw = (QtTableView *)this;
             r = yCellOffs;
-            int h = minViewY() - yCellDelta; //##arnt3
+            int h = minViewY() - yCellDelta;
             int oldH = h;
             Q_ASSERT(r < nRows);
             while (r < nRows)
             {
                 oldH = h;
-                h += tw->cellHeight(r); // Start of next cell
+                h += cellHeight(r); // Start of next cell
                 if (yPos < h)
                     break;
                 r++;
@@ -1313,6 +1112,13 @@ int QtTableView::findRawRow(int yPos, int *cellMaxY, int *cellMinY,
                 *cellMinY = oldH;
         }
     }
+    else
+    {
+        if (cellMaxY)
+            *cellMaxY = 0;
+        if (cellMinY)
+            *cellMinY = 0;
+    }
     return r;
 }
 
@@ -1322,7 +1128,13 @@ int QtTableView::findRawCol(int xPos, int *cellMaxX, int *cellMinX,
 {
     int c = -1;
     if (nCols == 0)
+    {
+        if (cellMaxX)
+            *cellMaxX = 0;
+        if (cellMinX)
+            *cellMinX = 0;
         return c;
+    }
     if (goOutsideView || (xPos >= minViewX() && xPos <= maxViewX()))
     {
         if (xPos < minViewX())
@@ -1333,6 +1145,10 @@ int QtTableView::findRawCol(int xPos, int *cellMaxX, int *cellMinX,
                      "not supported. (%d,%d)",
                      name("unnamed"), xPos, xOffs);
 #endif
+            if (cellMaxX)
+                *cellMaxX = 0;
+            if (cellMinX)
+                *cellMinX = 0;
             return -1;
         }
         if (cellW)
@@ -1346,15 +1162,14 @@ int QtTableView::findRawCol(int xPos, int *cellMaxX, int *cellMinX,
         }
         else
         { // variable cell width
-            QtTableView *tw = (QtTableView *)this;
             c = xCellOffs;
-            int w = minViewX() - xCellDelta; //##arnt3
+            int w = minViewX() - xCellDelta;
             int oldW = w;
             Q_ASSERT(c < nCols);
             while (c < nCols)
             {
                 oldW = w;
-                w += tw->cellWidth(c); // Start of next cell
+                w += cellWidth(c); // Start of next cell
                 if (xPos < w)
                     break;
                 c++;
@@ -1365,6 +1180,13 @@ int QtTableView::findRawCol(int xPos, int *cellMaxX, int *cellMinX,
                 *cellMinX = oldW;
         }
     }
+    else
+    {
+        if (cellMaxX)
+            *cellMaxX = 0;
+        if (cellMinX)
+            *cellMinX = 0;
+    }
     return c;
 }
 
@@ -1448,10 +1270,9 @@ bool QtTableView::rowYPos(int row, int *yPos) const
             //##arnt3
             y = minViewY() - yCellDelta; // y of leftmost cell in view
             int r = yCellOffs;
-            QtTableView *tw = (QtTableView *)this;
             int maxY = maxViewY();
             while (r < row && y <= maxY)
-                y += tw->cellHeight(r++);
+                y += cellHeight(r++);
             if (y > maxY)
                 return false;
         }
@@ -1492,10 +1313,9 @@ bool QtTableView::colXPos(int col, int *xPos) const
             //##arnt3
             x = minViewX() - xCellDelta; // x of uppermost cell in view
             int c = xCellOffs;
-            QtTableView *tw = (QtTableView *)this;
             int maxX = maxViewX();
             while (c < col && x <= maxX)
-                x += tw->cellWidth(c++);
+                x += cellWidth(c++);
             if (x > maxX)
                 return false;
         }
@@ -1560,15 +1380,10 @@ int QtTableView::viewHeight() const
     return maxViewY(); /// - minViewY() + 1;
 }
 
-/*
-  \fn void QtTableView::updateScrollBars()
-  Updates the scroll bars' contents and presence to match the table's
-  state.  Generally, you should not need to call this.
-  \sa setTableFlags()
-  Updates the scroll bars' contents and presence to match the table's
-  state \c or \a f.
-  \sa setTableFlags()
-*/
+void QtTableView::updateScrollBars()
+{
+    updateScrollBars(horValue | verValue | horSteps | horRange | verSteps | verRange);
+}
 
 void QtTableView::updateScrollBars(uint f)
 {
@@ -1597,18 +1412,18 @@ void QtTableView::updateScrollBars(uint f)
         if (sbDirty & horSteps)
         {
             if (cellW)
-                hScrollBar->setSingleStep(qMin((int)cellW, viewWidth() / 2));
+                horizontalScrollBar()->setSingleStep(qMin((int)cellW, viewWidth() / 2));
             else
-                hScrollBar->setSingleStep(16);
-            hScrollBar->setPageStep(viewWidth());
+                horizontalScrollBar()->setSingleStep(16);
+            horizontalScrollBar()->setPageStep(viewWidth());
         }
 
         if (sbDirty & horRange)
         {
-            hScrollBar->setRange(0, maxXOffset());
+            horizontalScrollBar()->setRange(0, maxXOffset());
         }
         if (sbDirty & horValue)
-            hScrollBar->setValue(xOffs);
+            horizontalScrollBar()->setValue(xOffs);
     }
 
     if (testTableFlags(Tbl_vScrollBar) && (sbDirty & verMask) != 0)
@@ -1616,17 +1431,17 @@ void QtTableView::updateScrollBars(uint f)
         if (sbDirty & verSteps)
         {
             if (cellH)
-                vScrollBar->setSingleStep(qMin((int)cellH, viewHeight() / 2));
+                verticalScrollBar()->setSingleStep(qMin((int)cellH, viewHeight() / 2));
             else
-                vScrollBar->setSingleStep(16); // fttb! ###
-            vScrollBar->setPageStep(viewHeight());
+                verticalScrollBar()->setSingleStep(16); // fttb! ###
+            verticalScrollBar()->setPageStep(viewHeight());
         }
 
         if (sbDirty & verRange)
-            vScrollBar->setRange(0, maxYOffset());
+            verticalScrollBar()->setRange(0, maxYOffset());
 
         if (sbDirty & verValue)
-            vScrollBar->setValue(yOffs);
+            verticalScrollBar()->setValue(yOffs);
     }
 
     sbDirty = 0;
@@ -1634,23 +1449,17 @@ void QtTableView::updateScrollBars(uint f)
 }
 
 /*
-  Updates the scroll bars and internal state.
+  Updates the internal state.
 
   Call this function when the table view's total size is changed;
   typically because the result of cellHeight() or cellWidth() have changed.
   This function does not repaint the widget.
 */
-//->  updateViewSize();
-void QtTableView::updateTableSize()
+void QtTableView::updateOffsets()
 {
-    updateScrollBars(horSteps | horRange | verSteps | verRange);
-    return;
-    bool updateOn = updatesEnabled();
-    setAutoUpdate(false);
     int xofs = xOffset();
-    xOffs++; // so that setOffset will not return immediately
-    setOffset(xofs, yOffset(), false); // to calculate internal state correctly
-    setAutoUpdate(updateOn);
+    xOffs++; // for setOffset() not to return immediately
+    setOffset(xofs, yOffset(), false, false); // to calculate internal state correctly
 }
 
 /*
